@@ -36,16 +36,12 @@
 #include <dirent.h>
 #include <errno.h>
 #include "gst/gst-i18n-plugin.h"
-#include <gst/gst.h>
 
 /* taken from linux/cdrom.h */
 #define CD_MSF_OFFSET       150 /* MSF numbering offset of first frame */
 #define CD_SECS              60 /* seconds per minute */
 #define CD_FRAMES            75 /* frames per second */
 
-GST_DEBUG_CATEGORY_STATIC (cdparanoia_debug);
-#define GST_CAT_DEFAULT cdparanoia_debug
-
 #include "gstcdparanoia.h"
 
 
@@ -64,7 +60,11 @@ GST_STATIC_PAD_TEMPLATE ("src",
         "endianness = (int) BYTE_ORDER, "
         "signed = (boolean) true, "
         "width = (int) 16, "
-        "depth = (int) 16, " "rate = (int) 44100, " "channels = (int) 2")
+        "depth = (int) 16, "
+        "rate = (int) 44100, "
+        "channels = (int) 2, "
+        "chunksize = (int) " G_STRINGIFY (CD_FRAMESIZE_RAW)
+    )
     );
 
 
@@ -120,7 +120,6 @@ enum
 {
   ARG_0,
   ARG_LOCATION,
-  ARG_DEVICE,
   ARG_GENERIC_DEVICE,
   ARG_DEFAULT_SECTORS,
   ARG_SEARCH_OVERLAP,
@@ -138,7 +137,6 @@ enum
 static void cdparanoia_base_init (gpointer g_class);
 static void cdparanoia_class_init (CDParanoiaClass * klass);
 static void cdparanoia_init (CDParanoia * cdparanoia);
-static void cdparanoia_finalize (GObject * obj);
 
 static void cdparanoia_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec);
@@ -159,32 +157,44 @@ static void cdparanoia_set_index (GstElement * element, GstIndex * index);
 static GstIndex *cdparanoia_get_index (GstElement * element);
 
 
-static void cdparanoia_uri_handler_init (gpointer g_iface, gpointer iface_data);
-
-static void
-_do_init (GType cdparanoia_type)
-{
-  static const GInterfaceInfo urihandler_info = {
-    cdparanoia_uri_handler_init,
-    NULL,
-    NULL,
-  };
-
-  g_type_add_interface_static (cdparanoia_type, GST_TYPE_URI_HANDLER,
-      &urihandler_info);
-}
-
-GST_BOILERPLATE_FULL (CDParanoia, cdparanoia, GstElement, GST_TYPE_ELEMENT,
-    _do_init);
-
 static GstElementStateReturn cdparanoia_change_state (GstElement * element);
 
+
+static GstElementClass *parent_class = NULL;
 static guint cdparanoia_signals[LAST_SIGNAL] = { 0 };
 
-/* our two formats */
 static GstFormat track_format;
 static GstFormat sector_format;
 
+GType
+cdparanoia_get_type (void)
+{
+  static GType cdparanoia_type = 0;
+
+  if (!cdparanoia_type) {
+    static const GTypeInfo cdparanoia_info = {
+      sizeof (CDParanoiaClass),
+      cdparanoia_base_init,
+      NULL,
+      (GClassInitFunc) cdparanoia_class_init,
+      NULL,
+      NULL,
+      sizeof (CDParanoia),
+      0,
+      (GInstanceInitFunc) cdparanoia_init,
+    };
+
+    cdparanoia_type =
+        g_type_register_static (GST_TYPE_ELEMENT, "CDParanoia",
+        &cdparanoia_info, 0);
+
+    /* Register the track format */
+    track_format = gst_format_register ("track", "CD track");
+    sector_format = gst_format_register ("sector", "CD sector");
+  }
+  return cdparanoia_type;
+}
+
 static void
 cdparanoia_base_init (gpointer g_class)
 {
@@ -194,9 +204,6 @@ cdparanoia_base_init (gpointer g_class)
       gst_static_pad_template_get (&cdparanoia_src_template));
   gst_element_class_set_details (element_class, &cdparanoia_details);
 
-  /* Register the track and sector format */
-  track_format = gst_format_register ("track", "CD track");
-  sector_format = gst_format_register ("sector", "CD sector");
 }
 
 static void
@@ -227,12 +234,8 @@ cdparanoia_class_init (CDParanoiaClass * klass)
       NULL, NULL, g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1, G_TYPE_INT);
 
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_LOCATION,
-      g_param_spec_string ("location", "Location",
-          "CD device location (deprecated; use device)",
+      g_param_spec_string ("location", "location", "location",
           NULL, G_PARAM_READWRITE));
-  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_DEVICE,
-      g_param_spec_string ("device", "Device",
-          "CD device location", NULL, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_GENERIC_DEVICE,
       g_param_spec_string ("generic_device", "Generic device",
           "Use specified generic scsi device", NULL, G_PARAM_READWRITE));
@@ -273,20 +276,11 @@ cdparanoia_class_init (CDParanoiaClass * klass)
           "Type of checking to perform", GST_TYPE_PARANOIA_MODE, 0,
           G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_DISCID,
-      g_param_spec_string ("discid", "discid", "The disc id", NULL,
+      g_param_spec_string ("discid", "discid", "The dics id", NULL,
           G_PARAM_READABLE));
 
-  /* tags */
-  gst_tag_register ("discid", GST_TAG_FLAG_META, G_TYPE_STRING,
-      _("discid"), _("CDDA discid for metadata retrieval"),
-      gst_tag_merge_use_first);
-  gst_tag_register ("musicbrainz-discid", GST_TAG_FLAG_META, G_TYPE_STRING,
-      _("musicbrainz-discid"), _("Musicbrainz discid for metadata retrieval"),
-      gst_tag_merge_use_first);
-
   gobject_class->set_property = cdparanoia_set_property;
   gobject_class->get_property = cdparanoia_get_property;
-  gobject_class->finalize = cdparanoia_finalize;
 
   gstelement_class->change_state = cdparanoia_change_state;
   gstelement_class->set_index = cdparanoia_set_index;
@@ -324,24 +318,9 @@ cdparanoia_init (CDParanoia * cdparanoia)
   cdparanoia->abort_on_skip = FALSE;
 
   cdparanoia->total_seconds = 0;
-  cdparanoia->discont_sent = FALSE;
-  cdparanoia->uri = NULL;
-  cdparanoia->cur_track = -1;
-  cdparanoia->seek_request = -1;
-  cdparanoia->track_mode = FALSE;
-  cdparanoia->pending_metadata = NULL;
+  cdparanoia->discont_pending = FALSE;
 }
 
-static void
-cdparanoia_finalize (GObject * obj)
-{
-  CDParanoia *cdparanoia = CDPARANOIA (obj);
-
-  g_free (cdparanoia->uri);
-  cdparanoia->uri = NULL;
-
-  G_OBJECT_CLASS (parent_class)->finalize (obj);
-}
 
 static void
 cdparanoia_set_property (GObject * object, guint prop_id, const GValue * value,
@@ -355,9 +334,9 @@ cdparanoia_set_property (GObject * object, guint prop_id, const GValue * value,
   src = CDPARANOIA (object);
 
   switch (prop_id) {
-    case ARG_DEVICE:
     case ARG_LOCATION:
-      g_free (src->device);
+      if (src->device)
+        g_free (src->device);
       /* clear the filename if we get a NULL (is that possible?) */
       if (!g_ascii_strcasecmp (g_value_get_string (value), ""))
         src->device = NULL;
@@ -420,7 +399,6 @@ cdparanoia_get_property (GObject * object, guint prop_id, GValue * value,
   src = CDPARANOIA (object);
 
   switch (prop_id) {
-    case ARG_DEVICE:
     case ARG_LOCATION:
       g_value_set_string (value, src->device);
       break;
@@ -456,7 +434,7 @@ cdparanoia_get_property (GObject * object, guint prop_id, GValue * value,
       break;
     case ARG_DISCID:
       /**
-       * Due to possible autocorrections of start sectors of audio tracks on
+       * Due to possible autocorrections of start sectors of audio tracks on 
        * multisession cds, we can maybe not compute the correct discid.
        * So issue a warning.
        * See cdparanoia/interface/common-interface.c:FixupTOC
@@ -477,54 +455,6 @@ cdparanoia_callback (long inpos, int function)
 {
 }
 
-static guint
-get_first_sector (CDParanoia * src, guint track)
-{
-  if (track == src->d->tracks)
-    return src->last_sector + 1;
-  else
-    return cdda_track_firstsector (src->d, track + 1);
-}
-
-static guint
-get_relative (CDParanoia * src, guint track, guint sector)
-{
-  return sector - get_first_sector (src, track);
-}
-
-static void
-set_track (CDParanoia * src, guint track)
-{
-  src->cur_track = track;
-  g_free (src->uri);
-  src->uri = g_strdup_printf ("cdda://%d", track++);
-  src->track_mode = TRUE;
-}
-
-static gboolean
-is_track_switch (CDParanoia * src, guint sector)
-{
-  gint n;
-
-  if (!src->track_mode)
-    return FALSE;
-
-  if (sector < get_first_sector (src, src->cur_track) ||
-      sector >= get_first_sector (src, src->cur_track + 1)) {
-    /* get track */
-    for (n = 0; n < src->d->tracks; n++) {
-      if (sector >= get_first_sector (src, n) &&
-          sector < get_first_sector (src, n + 1))
-        break;
-    }
-    set_track (src, n);
-
-    return TRUE;
-  }
-
-  return FALSE;
-}
-
 static GstData *
 cdparanoia_get (GstPad * pad)
 {
@@ -535,16 +465,8 @@ cdparanoia_get (GstPad * pad)
 
   g_return_val_if_fail (GST_FLAG_IS_SET (src, CDPARANOIA_OPEN), NULL);
 
-  if (src->seek_request != -1) {
-    cdparanoia_event (src->srcpad,
-        gst_event_new_segment_seek (track_format |
-            GST_SEEK_METHOD_SET |
-            GST_SEEK_FLAG_FLUSH, src->seek_request - 1, src->seek_request));
-    src->seek_request = -1;
-  }
-
-  /* stop things appropriately */
-  if (src->cur_sector >= src->segment_end_sector) {
+  /* stop things apropriatly */
+  if (src->cur_sector > src->segment_end_sector) {
     GST_DEBUG ("setting EOS");
 
     buf = GST_BUFFER (gst_event_new (GST_EVENT_EOS));
@@ -554,68 +476,23 @@ cdparanoia_get (GstPad * pad)
     gint64 timestamp;
     GstFormat format;
 
+    /* read a sector */
+    cdda_buf = paranoia_read (src->p, cdparanoia_callback);
+
     /* convert the sequence sector number to a timestamp */
     format = GST_FORMAT_TIME;
     timestamp = 0LL;
-    gst_pad_convert (src->srcpad, sector_format,
-        get_relative (src, src->cur_track, src->cur_sector), &format,
-        &timestamp);
-
-    if (!src->discont_sent && (is_track_switch (src, src->cur_sector) ||
-            (src->prev_sec != src->cur_sector))) {
-      GstEvent *discont_ev;
-
-      if (src->cur_track == src->d->tracks) {
-        GST_DEBUG_OBJECT (src, "End of CD");
-        discont_ev = gst_event_new (GST_EVENT_EOS);
-        gst_element_set_eos (GST_ELEMENT (src));
-        return GST_DATA (discont_ev);
-      }
-
-      gst_pad_convert (src->srcpad, sector_format,
-          get_relative (src, src->cur_track, src->cur_sector), &format,
-          &timestamp);
-
-      if (src->flush_pending) {
-        src->flush_pending = FALSE;
-        GST_DEBUG_OBJECT (src, "Sending flush");
-        return GST_DATA (gst_event_new (GST_EVENT_FLUSH));
-      }
-
-      discont_ev =
-          gst_event_new_discontinuous (FALSE, GST_FORMAT_TIME, timestamp,
-          GST_FORMAT_UNDEFINED);
-
-      src->discont_sent = TRUE;
-      GST_DEBUG_OBJECT (src, "Sending discont to %" GST_TIME_FORMAT,
-          GST_TIME_ARGS (timestamp));
-      return GST_DATA (discont_ev);
-    }
-
-    if (src->pending_metadata) {
-      GstData *d = GST_DATA (src->pending_metadata);
-
-      src->pending_metadata = NULL;
-      return d;
-    }
-
-    src->discont_sent = FALSE;
-
-    /* read a sector */
-    cdda_buf = paranoia_read (src->p, cdparanoia_callback);
+    gst_pad_convert (src->srcpad, sector_format, src->seq, &format, &timestamp);
 
     /* have to copy the buffer for now since we don't own it... */
     /* FIXME must ask monty about allowing ownership transfer */
     buf = gst_buffer_new_and_alloc (CD_FRAMESIZE_RAW);
     memcpy (GST_BUFFER_DATA (buf), cdda_buf, CD_FRAMESIZE_RAW);
     GST_BUFFER_TIMESTAMP (buf) = timestamp;
-    gst_pad_convert (pad, GST_FORMAT_BYTES, CD_FRAMESIZE_RAW,
-        &format, &timestamp);
-    GST_BUFFER_DURATION (buf) = timestamp;
 
     /* update current sector */
     src->cur_sector++;
-    src->prev_sec = src->cur_sector;
+    src->seq++;
   }
 
   /* we're done, push the buffer off now */
@@ -689,42 +566,10 @@ cddb_discid (gchar * discid, toc_msf * toc, gint tracks)
   sprintf (discid, "%08x", ((n % 0xff) << 24 | t << 8 | tracks));
 }
 
-#include "base64.h"
-#include "sha1.h"
-
-static void
-get_musicbrainz_discid (toc_msf * toc, TOC * xtoc, gint tracks, char *id)
-{
-  guchar digest[20], *ptr;
-  gchar tmp[9];
-  gulong i;
-  SHA_INFO sha;
-
-  /* generate SHA digest */
-  sha_init (&sha);
-  sprintf (tmp, "%02X", xtoc[0].bTrack);
-  sha_update (&sha, (SHA_BYTE *) tmp, 2);
-  sprintf (tmp, "%02X", xtoc[tracks - 1].bTrack);
-  sha_update (&sha, (SHA_BYTE *) tmp, 2);
-  sprintf (tmp, "%08X", toc[tracks].f);
-  sha_update (&sha, (SHA_BYTE *) tmp, 8);
-  for (i = 0; i < 99; i++) {
-    sprintf (tmp, "%08X", (i < tracks) ? toc[i].f : 0);
-    sha_update (&sha, (SHA_BYTE *) tmp, 8);
-  }
-  sha_final (digest, &sha);
-
-  /* re-encode to base64 */
-  ptr = rfc822_binary (digest, 20, &i);
-  memcpy (id, ptr, i);
-  id[i] = '\0';
-  free (ptr);
-}
-
 /* get all the cddb info at once */
 static void
-get_cddb_info (TOC * toc, gint tracks, gchar * discid,
-    gchar * musicbrainz_discid, gint64 * offsets, gint64 * total_seconds)
+get_cddb_info (TOC * toc, gint tracks, gchar * discid, gint64 * offsets,
+    gint64 * total_seconds)
 {
   toc_msf msf_toc[MAXTRK];
   gint i;
@@ -739,7 +584,6 @@ get_cddb_info (TOC * toc, gint tracks, gchar * discid,
 
   *total_seconds = msf_toc[tracks].f / 75;
 
-  get_musicbrainz_discid (msf_toc, toc, tracks, musicbrainz_discid);
 }
 
 static void
@@ -750,7 +594,7 @@ add_index_associations (CDParanoia * src)
   for (i = 0; i < src->d->tracks; i++) {
     gint64 sector;
 
-    sector = get_first_sector (src, i);
+    sector = cdda_track_firstsector (src->d, i + 1);
     gst_index_add_association (src->index, src->index_id,
         GST_ASSOCIATION_FLAG_KEY_UNIT,
         track_format, i,
@@ -775,10 +619,8 @@ add_index_associations (CDParanoia * src)
 static gboolean
 cdparanoia_open (CDParanoia * src)
 {
-  GstTagList *taglist;
   gint i;
   gint paranoia_mode;
-  char musicbrainz_discid[33];
 
   g_return_val_if_fail (!GST_FLAG_IS_SET (src, CDPARANOIA_OPEN), FALSE);
 
@@ -814,8 +656,7 @@ cdparanoia_open (CDParanoia * src)
   /* open the disc */
   if (cdda_open (src->d)) {
     GST_ELEMENT_ERROR (src, RESOURCE, OPEN_READ,
-        (_("Could not open CD device %s for reading."),
-            src->d->cdda_device_name), ("cdda_open failed"));
+        (_("Could not open CD device for reading.")), ("cdda_open failed"));
     cdda_close (src->d);
     src->d = NULL;
     return FALSE;
@@ -825,21 +666,15 @@ cdparanoia_open (CDParanoia * src)
    * when leaving the function it clobbers the allocated mem and all is lost bugger
    */
 
-  get_cddb_info (&src->d->disc_toc[0], src->d->tracks - src->d->cd_extra,
-      src->discid, musicbrainz_discid, src->offsets, &src->total_seconds);
+  get_cddb_info (&src->d->disc_toc[0], src->d->tracks, src->discid,
+      src->offsets, &src->total_seconds);
 
   g_object_freeze_notify (G_OBJECT (src));
   g_object_notify (G_OBJECT (src), "discid");
   g_object_thaw_notify (G_OBJECT (src));
 
-  taglist = gst_tag_list_new ();
-  gst_tag_list_add (taglist, GST_TAG_MERGE_APPEND, "discid", src->discid,
-      "musicbrainz-discid", musicbrainz_discid, NULL);
-  gst_element_found_tags (GST_ELEMENT (src), taglist);
-  src->pending_metadata = gst_event_new_tag (taglist);
-
   if (src->toc_bias) {
-    src->toc_offset -= get_first_sector (src, 0);
+    src->toc_offset -= cdda_track_firstsector (src->d, 1);
   }
   for (i = 0; i < src->d->tracks + 1; i++) {
     src->d->disc_toc[i].dwStartSector += src->toc_offset;
@@ -849,16 +684,9 @@ cdparanoia_open (CDParanoia * src)
     cdda_speed_set (src->d, src->read_speed);
   }
 
-  /* save these ones - skip lead-in in
-   * in track mode, we need last_sector set to play the last track.
-   */
+  /* save thse ones */
+  src->first_sector = cdda_disc_firstsector (src->d);
   src->last_sector = cdda_disc_lastsector (src->d);
-  if (src->track_mode) {
-    src->first_sector = get_first_sector (src, src->cur_track);
-    src->last_sector = get_first_sector (src, src->cur_track + 1) - 1;
-  } else {
-    src->first_sector = cdda_track_firstsector (src->d, 1);
-  }
 
   /* this is the default segment we will play */
   src->segment_start_sector = src->first_sector;
@@ -882,7 +710,6 @@ cdparanoia_open (CDParanoia * src)
   }
 
   src->cur_sector = src->first_sector;
-  src->prev_sec = src->cur_sector;
   paranoia_seek (src->p, src->cur_sector, SEEK_SET);
   GST_DEBUG ("successfully seek'd to beginning of disk");
 
@@ -927,8 +754,10 @@ cdparanoia_change_state (GstElement * element)
   switch (GST_STATE_TRANSITION (element)) {
     case GST_STATE_NULL_TO_READY:
       if (!cdparanoia_open (CDPARANOIA (element))) {
+        g_warning ("cdparanoia: failed opening cd");
         return GST_STATE_FAILURE;
       }
+      cdparanoia->seq = 0;
       break;
     case GST_STATE_READY_TO_PAUSED:
       break;
@@ -938,15 +767,9 @@ cdparanoia_change_state (GstElement * element)
       break;
     case GST_STATE_PAUSED_TO_READY:
       /* FIXME: Need code here to reset element to start of cd */
-      if (cdparanoia->pending_metadata) {
-        gst_event_unref (cdparanoia->pending_metadata);
-        cdparanoia->pending_metadata = NULL;
-      }
-      cdparanoia->track_mode = FALSE;
       break;
     case GST_STATE_READY_TO_NULL:
       cdparanoia_close (CDPARANOIA (element));
-      cdparanoia->seek_request = -1;
       break;
     default:
       break;
@@ -998,114 +821,50 @@ cdparanoia_event (GstPad * pad, GstEvent * event)
       offset = GST_EVENT_SEEK_OFFSET (event);
       endoffset = GST_EVENT_SEEK_ENDOFFSET (event);
 
-      if (format == track_format) {
-        gint track = 0, endtrack = 0;
-
-        switch (GST_EVENT_SEEK_METHOD (event)) {
-          case GST_SEEK_METHOD_SET:
-            track = offset;
-            endtrack = endoffset;
-            break;
-          case GST_SEEK_METHOD_END:
-            track = src->d->tracks - offset;
-            endtrack = src->d->tracks - endoffset;
-            break;
-          case GST_SEEK_METHOD_CUR:
-            track = src->cur_track + offset;
-            endtrack = src->cur_track + endoffset;
-            break;
-        }
-        if (track < 0 || track >= src->d->tracks ||
-            (endoffset != -1 && (endtrack < 0
-                    || endtrack >= src->d->tracks + 1))) {
-          GST_WARNING ("track %d or endtrack %d is out of range (%d avail)",
-              track, endtrack, src->d->tracks);
-          goto error;
-        }
-
-        set_track (src, track);
-        seg_start_sector = get_first_sector (src, track);
-        if (endoffset != -1)
-          seg_end_sector = get_first_sector (src, endtrack);
-        GST_LOG ("Seeking to track %d-%d (sector %" G_GINT64_FORMAT "-%"
-            G_GINT64_FORMAT ")", track, endtrack, seg_start_sector,
-            seg_end_sector);
-      } else {
-        /* from here on, all seeks are relative to the current track */
-
-        /* we can only seek on sectors, so we convert the requested
-         * offsets to sectors first */
-        if (offset != -1) {
-          res &= gst_pad_convert (src->srcpad, format, offset,
-              &sector_format, &seg_start_sector);
-        }
-        if (endoffset != -1) {
-          res &= gst_pad_convert (src->srcpad, format, endoffset,
-              &sector_format, &seg_end_sector);
-        }
-
-        if (!res) {
-          GST_DEBUG ("could not convert offsets to sectors");
-          goto error;
-        }
-
-        switch (GST_EVENT_SEEK_METHOD (event)) {
-          case GST_SEEK_METHOD_SET:
-            /* values are set for regular seek set */
-            if (seg_start_sector != -1) {
-              seg_start_sector += get_first_sector (src, src->cur_track);
-            }
-            if (seg_end_sector != -1) {
-              seg_end_sector += get_first_sector (src, src->cur_track);
-            }
-            break;
-          case GST_SEEK_METHOD_CUR:
-            if (seg_start_sector != -1) {
-              seg_start_sector += src->cur_sector;
-            }
-            if (seg_end_sector != -1) {
-              seg_end_sector += src->cur_sector;
-            }
-            break;
-          case GST_SEEK_METHOD_END:
-            if (seg_start_sector != -1) {
-              seg_start_sector += get_first_sector (src, src->cur_track + 1);
-            }
-            if (seg_end_sector != -1) {
-              seg_end_sector += get_first_sector (src, src->cur_track + 1);
-            }
-            break;
-          default:
-            goto error;
-        }
-
-        /* FIXME: get_first_sector() has inverted logic, so we need this
-         * hack here for this to work. Bleh. */
-        if (src->track_mode) {
-          if (seg_start_sector != -1) {
-            /* make sure it's in range */
-            if (seg_start_sector < get_first_sector (src, src->cur_track) ||
-                seg_start_sector >= get_first_sector (src,
-                    src->cur_track + 1)) {
-              GST_WARNING ("Seek out of range (sector %" G_GINT64_FORMAT
-                  " is not in track %d)", seg_start_sector, src->cur_track);
-              goto error;
-            }
-          }
-
-          if (seg_end_sector != -1) {
-            if (seg_end_sector < get_first_sector (src, src->cur_track) ||
-                seg_end_sector >= get_first_sector (src, src->cur_track + 1)) {
-              GST_WARNING ("Seek out of range (sector %" G_GINT64_FORMAT
-                  " is not in track %d)", seg_end_sector, src->cur_track);
-              seg_end_sector = -1;
-            }
-          }
-        }
+      /* we can only seek on sectors, so we convert the requested
+       * offsets to sectors first */
+      if (offset != -1) {
+        res &= gst_pad_convert (src->srcpad, format, offset,
+            &sector_format, &seg_start_sector);
+      }
+      if (endoffset != -1) {
+        res &= gst_pad_convert (src->srcpad, format, endoffset,
+            &sector_format, &seg_end_sector);
       }
 
+      if (!res) {
+        GST_DEBUG ("could not convert offsets to sectors");
+        goto error;
+      }
+
+      switch (GST_EVENT_SEEK_METHOD (event)) {
+        case GST_SEEK_METHOD_SET:
+          /* values are set for regular seek set */
+          break;
+        case GST_SEEK_METHOD_CUR:
+          if (seg_start_sector != -1) {
+            seg_start_sector += src->cur_sector;
+          }
+          if (seg_end_sector != -1) {
+            seg_end_sector += src->cur_sector;
+          }
+          break;
+        case GST_SEEK_METHOD_END:
+          if (seg_start_sector != -1) {
+            seg_start_sector = src->last_sector - seg_start_sector;
+          }
+          if (seg_end_sector != -1) {
+            seg_end_sector = src->last_sector - seg_end_sector;
+          }
+          break;
+        default:
+          goto error;
+      }
       /* do we need to update the start sector? */
       if (seg_start_sector != -1) {
+        seg_start_sector = CLAMP (seg_start_sector,
+            src->first_sector, src->last_sector);
+
         if (paranoia_seek (src->p, seg_start_sector, SEEK_SET) > -1) {
           GST_DEBUG ("seeked to %" G_GINT64_FORMAT, seg_start_sector);
 
@@ -1116,10 +875,11 @@ cdparanoia_event (GstPad * pad, GstEvent * event)
         }
       }
       if (seg_end_sector != -1) {
+        seg_end_sector = CLAMP (seg_end_sector,
+            src->first_sector, src->last_sector);
         src->segment_end_sector = seg_end_sector;
       }
-      src->flush_pending = GST_EVENT_SEEK_FLAGS (event) & GST_SEEK_FLAG_FLUSH;
-      GST_DEBUG ("configured for %d -> %d sectors",
+      GST_DEBUG ("configured for %d -> %d sectors\n",
           src->segment_start_sector, src->segment_end_sector);
       break;
     }
@@ -1216,14 +976,14 @@ cdparanoia_convert (GstPad * pad,
       break;
     default:
     {
-      gint64 sector;
+      gint sector;
 
       if (src_format == track_format) {
         /* some sanity checks */
         if (src_value < 0 || src_value > src->d->tracks)
           return FALSE;
 
-        sector = get_first_sector (src, src_value);
+        sector = cdda_track_firstsector (src->d, src_value + 1);
       } else if (src_format == sector_format) {
         sector = src_value;
       } else {
@@ -1244,11 +1004,10 @@ cdparanoia_convert (GstPad * pad,
             *dest_value = sector;
           } else if (*dest_format == track_format) {
             /* if we go past the last sector, make sure to report the last track */
-            if (sector > src->last_sector - src->first_sector)
+            if (sector > src->last_sector)
               *dest_value = cdda_sector_gettrack (src->d, src->last_sector);
             else
-              *dest_value = cdda_sector_gettrack (src->d,
-                  sector + src->first_sector) - 1;
+              *dest_value = cdda_sector_gettrack (src->d, sector) - 1;
           } else {
             return FALSE;
           }
@@ -1271,7 +1030,6 @@ cdparanoia_get_query_types (GstPad * pad)
     GST_QUERY_SEGMENT_END,
     0
   };
-
   return src_query_types;
 }
 
@@ -1292,34 +1050,21 @@ cdparanoia_query (GstPad * pad, GstQueryType type,
     case GST_QUERY_TOTAL:
       /* we take the last sector + 1 so that we also have the full
        * size of that last sector */
-      if (*format == track_format) {
-        *value = src->d->tracks;
-        res = TRUE;
-      } else {
-        res = gst_pad_convert (src->srcpad, sector_format,
-            get_first_sector (src, src->cur_track + 1) -
-            get_first_sector (src, src->cur_track), format, value);
-      }
+      res = gst_pad_convert (src->srcpad,
+          sector_format, src->last_sector + 1, format, value);
       break;
     case GST_QUERY_POSITION:
       /* bring our current sector to the requested format */
-      if (*format == track_format) {
-        *value = src->cur_track;
-        res = TRUE;
-      } else {
-        res = gst_pad_convert (src->srcpad, sector_format,
-            get_relative (src, src->cur_track, src->cur_sector), format, value);
-      }
+      res = gst_pad_convert (src->srcpad,
+          sector_format, src->cur_sector, format, value);
       break;
     case GST_QUERY_START:
       res = gst_pad_convert (src->srcpad,
-          sector_format, src->segment_start_sector - src->first_sector,
-          format, value);
+          sector_format, src->segment_start_sector, format, value);
       break;
     case GST_QUERY_SEGMENT_END:
       res = gst_pad_convert (src->srcpad,
-          sector_format, src->segment_end_sector - src->first_sector,
-          format, value);
+          sector_format, src->segment_end_sector, format, value);
       break;
     default:
       res = FALSE;
@@ -1356,9 +1101,6 @@ cdparanoia_get_index (GstElement * element)
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  GST_DEBUG_CATEGORY_INIT (cdparanoia_debug, "cdparanoia", 0,
-      "CDDA reading through the cdparanoia library");
-
   if (!gst_element_register (plugin, "cdparanoia", GST_RANK_NONE,
           GST_TYPE_CDPARANOIA))
     return FALSE;
@@ -1366,67 +1108,6 @@ plugin_init (GstPlugin * plugin)
   return TRUE;
 }
 
-/*** GSTURIHANDLER INTERFACE *************************************************/
-
-static guint
-cdparanoia_uri_get_type (void)
-{
-  return GST_URI_SRC;
-}
-static gchar **
-cdparanoia_uri_get_protocols (void)
-{
-  static gchar *protocols[] = { "cdda", NULL };
-
-  return protocols;
-}
-static const gchar *
-cdparanoia_uri_get_uri (GstURIHandler * handler)
-{
-  CDParanoia *cdparanoia = CDPARANOIA (handler);
-
-  return cdparanoia->uri;
-}
-
-static gboolean
-cdparanoia_uri_set_uri (GstURIHandler * handler, const gchar * uri)
-{
-  gchar *protocol, *location;
-  gboolean ret;
-
-  CDParanoia *cdparanoia = CDPARANOIA (handler);
-
-  ret = TRUE;
-
-  protocol = gst_uri_get_protocol (uri);
-  if (strcmp (protocol, "cdda") != 0) {
-    g_free (protocol);
-    return FALSE;
-  }
-  g_free (protocol);
-  location = gst_uri_get_location (uri);
-  if (sscanf (location, "%d", &cdparanoia->cur_track) == 1) {
-    cdparanoia->track_mode = TRUE;
-    cdparanoia->cur_track--;
-  } else {
-    cdparanoia->track_mode = FALSE;
-  }
-  g_free (location);
-
-  return ret;
-}
-
-static void
-cdparanoia_uri_handler_init (gpointer g_iface, gpointer iface_data)
-{
-  GstURIHandlerInterface *iface = (GstURIHandlerInterface *) g_iface;
-
-  iface->get_type = cdparanoia_uri_get_type;
-  iface->get_protocols = cdparanoia_uri_get_protocols;
-  iface->get_uri = cdparanoia_uri_get_uri;
-  iface->set_uri = cdparanoia_uri_set_uri;
-}
-
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
     GST_VERSION_MINOR,
     "cdparanoia",
