@@ -33,9 +33,7 @@
 #include "gst/gst-i18n-plugin.h"
 
 #include "gstgnomevfs.h"
-#include "gstgnomevfsuri.h"
 
-#include <stdlib.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/time.h>
@@ -54,9 +52,6 @@
 /* gnome-vfs.h doesn't include the following header, which we need: */
 #include <libgnomevfs/gnome-vfs-standard-callbacks.h>
 
-GST_DEBUG_CATEGORY_EXTERN (gnomevfs_debug);
-#define GST_CAT_DEFAULT gnomevfs_debug
-
 
 #define GST_TYPE_GNOMEVFSSRC \
   (gst_gnomevfssrc_get_type())
@@ -77,7 +72,7 @@ typedef enum
 {
   GST_GNOMEVFSSRC_OPEN = GST_ELEMENT_FLAG_LAST,
 
-  GST_GNOMEVFSSRC_FLAG_LAST = GST_ELEMENT_FLAG_LAST + 2
+  GST_GNOMEVFSSRC_FLAG_LAST = GST_ELEMENT_FLAG_LAST + 2,
 }
 GstGnomeVFSSrcFlags;
 
@@ -87,18 +82,16 @@ typedef struct _GstGnomeVFSSrcClass GstGnomeVFSSrcClass;
 struct _GstGnomeVFSSrc
 {
   GstElement element;
-
   /* pads */
   GstPad *srcpad;
 
+  /* filename */
+  gchar *filename;
   /* uri */
   GnomeVFSURI *uri;
-  gchar *uri_name;
 
   /* handle */
   GnomeVFSHandle *handle;
-  gboolean own_handle;
-
   /* Seek stuff */
   gboolean need_flush;
 
@@ -112,7 +105,6 @@ struct _GstGnomeVFSSrc
   gboolean iradio_mode;
   gboolean http_callbacks_pushed;
   gboolean seekable;
-  GstTagList *icy_taglist;
 
   gint icy_metaint;
   GnomeVFSFileSize icy_count;
@@ -198,16 +190,13 @@ enum
   ARG_IRADIO_GENRE,
   ARG_IRADIO_URL,
   ARG_IRADIO_TITLE,
-  ARG_SEEKABLE
+  ARG_SEEKABLE,
 };
 
 static void gst_gnomevfssrc_base_init (gpointer g_class);
 static void gst_gnomevfssrc_class_init (GstGnomeVFSSrcClass * klass);
 static void gst_gnomevfssrc_init (GstGnomeVFSSrc * gnomevfssrc);
-static void gst_gnomevfssrc_finalize (GObject * object);
-
-static void gst_gnomevfssrc_uri_handler_init (gpointer g_iface,
-    gpointer iface_data);
+static void gst_gnomevfssrc_dispose (GObject * object);
 
 static void gst_gnomevfssrc_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec);
@@ -250,17 +239,10 @@ gst_gnomevfssrc_get_type (void)
       0,
       (GInstanceInitFunc) gst_gnomevfssrc_init,
     };
-    static const GInterfaceInfo urihandler_info = {
-      gst_gnomevfssrc_uri_handler_init,
-      NULL,
-      NULL
-    };
 
     gnomevfssrc_type =
         g_type_register_static (GST_TYPE_ELEMENT,
         "GstGnomeVFSSrc", &gnomevfssrc_info, 0);
-    g_type_add_interface_static (gnomevfssrc_type, GST_TYPE_URI_HANDLER,
-        &urihandler_info);
   }
   return gnomevfssrc_type;
 }
@@ -288,7 +270,7 @@ gst_gnomevfssrc_class_init (GstGnomeVFSSrcClass * klass)
       "bytesperread", ARG_BYTESPERREAD, G_PARAM_READWRITE,
       "location", ARG_LOCATION, G_PARAM_READWRITE, NULL);
 
-  gobject_class->finalize = gst_gnomevfssrc_finalize;
+  gobject_class->dispose = gst_gnomevfssrc_dispose;
 
   g_object_class_install_property (gobject_class,
       ARG_HANDLE,
@@ -349,7 +331,6 @@ gst_gnomevfssrc_init (GstGnomeVFSSrc * gnomevfssrc)
   gst_element_add_pad (GST_ELEMENT (gnomevfssrc), gnomevfssrc->srcpad);
 
   gnomevfssrc->uri = NULL;
-  gnomevfssrc->uri_name = NULL;
   gnomevfssrc->handle = NULL;
   gnomevfssrc->curoffset = 0;
   gnomevfssrc->bytes_per_read = 4096;
@@ -385,7 +366,7 @@ gst_gnomevfssrc_init (GstGnomeVFSSrc * gnomevfssrc)
 }
 
 static void
-gst_gnomevfssrc_finalize (GObject * object)
+gst_gnomevfssrc_dispose (GObject * object)
 {
   GstGnomeVFSSrc *src = GST_GNOMEVFSSRC (object);
 
@@ -398,77 +379,21 @@ gst_gnomevfssrc_finalize (GObject * object)
   }
   g_static_mutex_unlock (&count_lock);
 
-  if (src->uri) {
-    gnome_vfs_uri_unref (src->uri);
-    src->uri = NULL;
-  }
-
-  if (src->uri_name) {
-    g_free (src->uri_name);
-    src->uri_name = NULL;
-  }
-
+  g_free (src->filename);
+  src->filename = NULL;
   g_mutex_free (src->audiocast_udpdata_mutex);
   g_mutex_free (src->audiocast_queue_mutex);
 
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
-static guint
-gst_gnomevfssrc_uri_get_type (void)
-{
-  return GST_URI_SRC;
-}
-
-static gchar **
-gst_gnomevfssrc_uri_get_protocols (void)
-{
-  static gchar **protocols = NULL;
-
-  if (!protocols)
-    protocols = gst_gnomevfs_get_supported_uris ();
-
-  return protocols;
-}
-
-static const gchar *
-gst_gnomevfssrc_uri_get_uri (GstURIHandler * handler)
-{
-  GstGnomeVFSSrc *src = GST_GNOMEVFSSRC (handler);
-
-  return src->uri_name;
-}
-
-static gboolean
-gst_gnomevfssrc_uri_set_uri (GstURIHandler * handler, const gchar * uri)
-{
-  GstGnomeVFSSrc *src = GST_GNOMEVFSSRC (handler);
-
-  if (GST_STATE (src) == GST_STATE_PLAYING ||
-      GST_STATE (src) == GST_STATE_PAUSED)
-    return FALSE;
-
-  g_object_set (G_OBJECT (src), "location", uri, NULL);
-
-  return TRUE;
-}
-
-static void
-gst_gnomevfssrc_uri_handler_init (gpointer g_iface, gpointer iface_data)
-{
-  GstURIHandlerInterface *iface = (GstURIHandlerInterface *) g_iface;
-
-  iface->get_type = gst_gnomevfssrc_uri_get_type;
-  iface->get_protocols = gst_gnomevfssrc_uri_get_protocols;
-  iface->get_uri = gst_gnomevfssrc_uri_get_uri;
-  iface->set_uri = gst_gnomevfssrc_uri_set_uri;
-}
 
 static void
 gst_gnomevfssrc_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec)
 {
   GstGnomeVFSSrc *src;
+  const gchar *location;
   gchar cwd[PATH_MAX];
 
   /* it's not null if we got it, but it might not be ours */
@@ -479,51 +404,42 @@ gst_gnomevfssrc_set_property (GObject * object, guint prop_id,
   switch (prop_id) {
     case ARG_LOCATION:
       /* the element must be stopped or paused in order to do this */
-      if (GST_STATE (src) == GST_STATE_PLAYING ||
-          GST_STATE (src) == GST_STATE_PAUSED)
+      if (GST_STATE (src) == GST_STATE_PLAYING)
         break;
 
-      if (src->uri) {
-        gnome_vfs_uri_unref (src->uri);
-        src->uri = NULL;
-      }
-      if (src->uri_name) {
-        g_free (src->uri_name);
-        src->uri_name = NULL;
-      }
-
-      if (g_value_get_string (value)) {
-        const gchar *location = g_value_get_string (value);
+      g_free (src->filename);
 
+      /* clear the filename if we get a NULL */
+      if (g_value_get_string (value) == NULL) {
+        gst_element_set_state (GST_ELEMENT (object), GST_STATE_NULL);
+        src->filename = NULL;
+      } else {
+        /* otherwise set the new filename */
+        location = g_value_get_string (value);
+        /* if it's not a proper uri, default to file: -- this
+         * is a crude test */
         if (!strchr (location, ':')) {
           gchar *newloc = gnome_vfs_escape_path_string (location);
 
           if (*newloc == '/')
-            src->uri_name = g_strdup_printf ("file://%s", newloc);
+            src->filename = g_strdup_printf ("file://%s", newloc);
           else
-            src->uri_name =
+            src->filename =
                 g_strdup_printf ("file://%s/%s", getcwd (cwd, PATH_MAX),
                 newloc);
           g_free (newloc);
         } else
-          src->uri_name = g_strdup (location);
+          src->filename = g_strdup (g_value_get_string (value));
+      }
 
-        src->uri = gnome_vfs_uri_new (src->uri_name);
+      if ((GST_STATE (src) == GST_STATE_PAUSED)
+          && (src->filename != NULL)) {
+        gst_gnomevfssrc_close_file (src);
+        gst_gnomevfssrc_open_file (src);
       }
       break;
     case ARG_HANDLE:
-      if (GST_STATE (src) == GST_STATE_NULL ||
-          GST_STATE (src) == GST_STATE_READY) {
-        if (src->uri) {
-          gnome_vfs_uri_unref (src->uri);
-          src->uri = NULL;
-        }
-        if (src->uri_name) {
-          g_free (src->uri_name);
-          src->uri_name = NULL;
-        }
-        src->handle = g_value_get_pointer (value);
-      }
+      src->handle = g_value_get_pointer (value);
       break;
     case ARG_BYTESPERREAD:
       src->bytes_per_read = g_value_get_int (value);
@@ -550,7 +466,7 @@ gst_gnomevfssrc_get_property (GObject * object, guint prop_id, GValue * value,
 
   switch (prop_id) {
     case ARG_LOCATION:
-      g_value_set_string (value, src->uri_name);
+      g_value_set_string (value, src->filename);
       break;
     case ARG_BYTESPERREAD:
       g_value_set_int (value, src->bytes_per_read);
@@ -628,7 +544,7 @@ audiocast_init (GstGnomeVFSSrc * src)
 
   if (!src->iradio_mode)
     return TRUE;
-  GST_DEBUG_OBJECT (src, "audiocast: registering listener");
+  GST_DEBUG ("audiocast: registering listener");
   if (audiocast_register_listener (&src->audiocast_port,
           &src->audiocast_fd) < 0) {
     GST_ELEMENT_ERROR (src, RESOURCE, OPEN_READ, (NULL),
@@ -636,7 +552,7 @@ audiocast_init (GstGnomeVFSSrc * src)
     close (src->audiocast_fd);
     return FALSE;
   }
-  GST_DEBUG_OBJECT (src, "audiocast: creating pipe");
+  GST_DEBUG ("audiocast: creating pipe");
   src->audiocast_notify_queue = NULL;
   if (pipe (pipefds) < 0) {
     close (src->audiocast_fd);
@@ -644,7 +560,7 @@ audiocast_init (GstGnomeVFSSrc * src)
   }
   src->audiocast_thread_die_infd = pipefds[0];
   src->audiocast_thread_die_outfd = pipefds[1];
-  GST_DEBUG_OBJECT (src, "audiocast: creating audiocast thread");
+  GST_DEBUG ("audiocast: creating audiocast thread");
   src->audiocast_thread =
       g_thread_create ((GThreadFunc) audiocast_thread_run, src, TRUE, &error);
   if (error != NULL) {
@@ -696,40 +612,16 @@ static void
 audiocast_do_notifications (GstGnomeVFSSrc * src)
 {
   /* Send any pending notifications we got from the UDP thread. */
-  GList *entry;
-  GstTagList *taglist;
-  gboolean set_taglist = FALSE;
+  if (src->iradio_mode) {
+    GList *entry;
 
-  if (!src->iradio_mode)
-    return;
-
-  if (src->icy_taglist == NULL) {
-    taglist = gst_tag_list_new ();
-  } else {
-    taglist = src->icy_taglist;
-    set_taglist = TRUE;
+    g_mutex_lock (src->audiocast_queue_mutex);
+    for (entry = src->audiocast_notify_queue; entry; entry = entry->next)
+      g_object_notify (G_OBJECT (src), (const gchar *) entry->data);
+    g_list_free (src->audiocast_notify_queue);
+    src->audiocast_notify_queue = NULL;
+    g_mutex_unlock (src->audiocast_queue_mutex);
   }
-
-  g_mutex_lock (src->audiocast_queue_mutex);
-  for (entry = src->audiocast_notify_queue; entry; entry = entry->next) {
-    g_object_notify (G_OBJECT (src), (const gchar *) entry->data);
-
-    if (strcmp (entry->data, "iradio-url") == 0) {
-      gst_tag_list_add (taglist, GST_TAG_MERGE_REPLACE, GST_TAG_LOCATION,
-          src->iradio_url, NULL);
-    } else if (strcmp (entry->data, "iradio-title") == 0) {
-      gst_tag_list_add (taglist, GST_TAG_MERGE_REPLACE, GST_TAG_TITLE,
-          src->iradio_title, NULL);
-    }
-  }
-  g_list_free (src->audiocast_notify_queue);
-  src->audiocast_notify_queue = NULL;
-  g_mutex_unlock (src->audiocast_queue_mutex);
-
-  if (set_taglist)
-    src->icy_taglist = taglist;
-  else
-    gst_tag_list_free (taglist);
 }
 
 static gpointer
@@ -747,26 +639,22 @@ audiocast_thread_run (GstGnomeVFSSrc * src)
   FD_SET (src->audiocast_thread_die_infd, &fdset);
 
   while (1) {
-    GST_DEBUG_OBJECT (src, "audiocast thread: dropping into select");
+    GST_DEBUG ("audiocast thread: dropping into select");
     readset = fdset;
     if (select (FD_SETSIZE, &readset, NULL, NULL, NULL) < 0) {
-      GST_ELEMENT_ERROR (src, RESOURCE, OPEN_READ, (NULL),
-          ("Unable to select"));
+      perror ("select");
       return NULL;
     }
     if (FD_ISSET (src->audiocast_thread_die_infd, &readset)) {
       char buf[1];
 
-      GST_DEBUG_OBJECT (src, "audiocast thread: got die character");
-      if (read (src->audiocast_thread_die_infd, buf, 1) != 1) {
-        GST_ELEMENT_ERROR (src, RESOURCE, OPEN_READ, (NULL),
-            ("Unable to read die character"));
-      }
+      GST_DEBUG ("audiocast thread: got die character");
+      read (src->audiocast_thread_die_infd, buf, 1);
       close (src->audiocast_thread_die_infd);
       close (src->audiocast_fd);
       return NULL;
     }
-    GST_DEBUG_OBJECT (src, "audiocast thread: reading data");
+    GST_DEBUG ("audiocast thread: reading data");
     len =
         recvfrom (src->audiocast_fd, buf, sizeof (buf) - 1, 0,
         (struct sockaddr *) &from, &fromlen);
@@ -812,7 +700,7 @@ audiocast_thread_run (GstGnomeVFSSrc * src)
           g_mutex_lock (src->audiocast_queue_mutex);
           src->audiocast_notify_queue =
               g_list_append (src->audiocast_notify_queue, "iradio-title");
-          GST_DEBUG_OBJECT (src, "audiocast title: %s\n", src->iradio_title);
+          GST_DEBUG ("audiocast title: %s\n", src->iradio_title);
           g_mutex_unlock (src->audiocast_queue_mutex);
         } else if (!strncmp (lines[i], "x-audiocast-streamurl", 21)) {
           g_mutex_lock (src->audiocast_udpdata_mutex);
@@ -823,7 +711,7 @@ audiocast_thread_run (GstGnomeVFSSrc * src)
           g_mutex_lock (src->audiocast_queue_mutex);
           src->audiocast_notify_queue =
               g_list_append (src->audiocast_notify_queue, "iradio-url");
-          GST_DEBUG_OBJECT (src, "audiocast url: %s\n", src->iradio_title);
+          GST_DEBUG ("audiocast url: %s\n", src->iradio_title);
           g_mutex_unlock (src->audiocast_queue_mutex);
         } else if (!strncmp (lines[i], "x-audiocast-udpseqnr", 20)) {
           gchar outbuf[120];
@@ -837,7 +725,7 @@ audiocast_thread_run (GstGnomeVFSSrc * src)
                 strerror (errno));
             continue;
           }
-          GST_DEBUG_OBJECT (src, "sent audiocast ack: %s\n", outbuf);
+          GST_DEBUG ("sent audiocast ack: %s\n", outbuf);
         }
       }
       g_strfreev (lines);
@@ -858,13 +746,10 @@ audiocast_thread_kill (GstGnomeVFSSrc * src)
      metadata, then we don't need the
      audiocast metadata too.
    */
-  GST_DEBUG_OBJECT (src, "audiocast: writing die character");
-  if (write (src->audiocast_thread_die_outfd, "q", 1) != 1) {
-    GST_ELEMENT_ERROR (src, RESOURCE, OPEN_WRITE, (NULL),
-        ("Unable to write die character"));
-  }
+  GST_DEBUG ("audiocast: writing die character");
+  write (src->audiocast_thread_die_outfd, "q", 1);
   close (src->audiocast_thread_die_outfd);
-  GST_DEBUG_OBJECT (src, "audiocast: joining thread");
+  GST_DEBUG ("audiocast: joining thread");
   g_thread_join (src->audiocast_thread);
   src->audiocast_thread = NULL;
 }
@@ -879,7 +764,7 @@ gst_gnomevfssrc_send_additional_headers_callback (gconstpointer in,
 
   if (!src->iradio_mode)
     return;
-  GST_DEBUG_OBJECT (src, "sending headers\n");
+  GST_DEBUG ("sending headers\n");
 
   out_args->headers = g_list_append (out_args->headers,
       g_strdup ("icy-metadata:1\r\n"));
@@ -896,20 +781,11 @@ gst_gnomevfssrc_received_headers_callback (gconstpointer in,
   GstGnomeVFSSrc *src = GST_GNOMEVFSSRC (callback_data);
   GnomeVFSModuleCallbackReceivedHeadersIn *in_args =
       (GnomeVFSModuleCallbackReceivedHeadersIn *) in;
-  GstTagList *tags = NULL;
-  gboolean set_taglist = FALSE;
 
   /* This is only used for internet radio stuff right now */
   if (!src->iradio_mode)
     return;
 
-  if (src->icy_taglist) {
-    tags = src->icy_taglist;
-    set_taglist = TRUE;
-  } else {
-    tags = gst_tag_list_new ();
-  }
-
   for (i = in_args->headers; i; i = i->next) {
     char *data = (char *) i->data;
     char *key = data;
@@ -925,12 +801,9 @@ gst_gnomevfssrc_received_headers_callback (gconstpointer in,
 
     /* Icecast stuff */
     if (!strncmp (data, "icy-metaint:", 12)) {  /* ugh */
-      if (sscanf (data + 12, "%d", &icy_metaint) != 1) {
-        GST_ELEMENT_ERROR (src, RESOURCE, OPEN_READ, (NULL),
-            ("Could not parse icy-metaint header"));
-      }
+      sscanf (data + 12, "%d", &icy_metaint);
       src->icy_metaint = icy_metaint;
-      GST_DEBUG_OBJECT (src, "got icy-metaint %d, killing audiocast thread",
+      GST_DEBUG ("got icy-metaint %d, killing audiocast thread",
           src->icy_metaint);
       audiocast_thread_kill (src);
       continue;
@@ -943,67 +816,50 @@ gst_gnomevfssrc_received_headers_callback (gconstpointer in,
     else
       continue;
 
-    GST_DEBUG_OBJECT (src, "key: %s", key);
+    GST_DEBUG ("key: %s", key);
     if (!strncmp (key, "name", 4)) {
       g_free (src->iradio_name);
       src->iradio_name = gst_gnomevfssrc_unicodify (value);
-      if (src->iradio_name) {
+      if (src->iradio_name)
         g_object_notify (G_OBJECT (src), "iradio-name");
-        gst_tag_list_add (tags, GST_TAG_MERGE_REPLACE, GST_TAG_COMMENT,
-            src->iradio_name, NULL);
-        set_taglist = TRUE;
-      }
     } else if (!strncmp (key, "genre", 5)) {
       g_free (src->iradio_genre);
       src->iradio_genre = gst_gnomevfssrc_unicodify (value);
-      if (src->iradio_genre) {
+      if (src->iradio_genre)
         g_object_notify (G_OBJECT (src), "iradio-genre");
-        gst_tag_list_add (tags, GST_TAG_MERGE_REPLACE, GST_TAG_GENRE,
-            src->iradio_genre, NULL);
-        set_taglist = TRUE;
-      }
     } else if (!strncmp (key, "url", 3)) {
       g_free (src->iradio_url);
       src->iradio_url = gst_gnomevfssrc_unicodify (value);
-      if (src->iradio_url) {
+      if (src->iradio_url)
         g_object_notify (G_OBJECT (src), "iradio-url");
-        gst_tag_list_add (tags, GST_TAG_MERGE_REPLACE, GST_TAG_LOCATION,
-            src->iradio_url, NULL);
-        set_taglist = TRUE;
-      }
     }
   }
-
-  if (set_taglist)
-    src->icy_taglist = tags;
-  else
-    gst_tag_list_free (tags);
 }
 
 static void
-gst_gnomevfssrc_push_callbacks (GstGnomeVFSSrc * src)
+gst_gnomevfssrc_push_callbacks (GstGnomeVFSSrc * gnomevfssrc)
 {
-  if (src->http_callbacks_pushed)
+  if (gnomevfssrc->http_callbacks_pushed)
     return;
 
-  GST_DEBUG_OBJECT (src, "pushing callbacks");
+  GST_DEBUG ("pushing callbacks");
   gnome_vfs_module_callback_push
       (GNOME_VFS_MODULE_CALLBACK_HTTP_SEND_ADDITIONAL_HEADERS,
-      gst_gnomevfssrc_send_additional_headers_callback, src, NULL);
+      gst_gnomevfssrc_send_additional_headers_callback, gnomevfssrc, NULL);
   gnome_vfs_module_callback_push
       (GNOME_VFS_MODULE_CALLBACK_HTTP_RECEIVED_HEADERS,
-      gst_gnomevfssrc_received_headers_callback, src, NULL);
+      gst_gnomevfssrc_received_headers_callback, gnomevfssrc, NULL);
 
-  src->http_callbacks_pushed = TRUE;
+  gnomevfssrc->http_callbacks_pushed = TRUE;
 }
 
 static void
-gst_gnomevfssrc_pop_callbacks (GstGnomeVFSSrc * src)
+gst_gnomevfssrc_pop_callbacks (GstGnomeVFSSrc * gnomevfssrc)
 {
-  if (!src->http_callbacks_pushed)
+  if (!gnomevfssrc->http_callbacks_pushed)
     return;
 
-  GST_DEBUG_OBJECT (src, "popping callbacks");
+  GST_DEBUG ("popping callbacks");
   gnome_vfs_module_callback_pop
       (GNOME_VFS_MODULE_CALLBACK_HTTP_SEND_ADDITIONAL_HEADERS);
   gnome_vfs_module_callback_pop
@@ -1020,11 +876,9 @@ gst_gnomevfssrc_get_icy_metadata (GstGnomeVFSSrc * src)
   guchar *data;
   guchar *pos;
   gchar **tags;
-  GstTagList *taglist;
   int i;
-  gboolean set_taglist = FALSE;
 
-  GST_DEBUG_OBJECT (src, "reading icecast metadata");
+  GST_DEBUG ("reading icecast metadata");
 
   while (length == 0) {
     res = gnome_vfs_read (src->handle, &foobyte, 1, &length);
@@ -1037,7 +891,7 @@ gst_gnomevfssrc_get_icy_metadata (GstGnomeVFSSrc * src)
   if (metadata_length == 0)
     return;
 
-  data = g_new (guchar, metadata_length + 1);
+  data = g_new (gchar, metadata_length + 1);
   pos = data;
 
   while (pos - data < metadata_length) {
@@ -1053,24 +907,15 @@ gst_gnomevfssrc_get_icy_metadata (GstGnomeVFSSrc * src)
   }
 
   data[metadata_length] = 0;
-  tags = g_strsplit ((gchar *) data, "';", 0);
-  if (src->icy_taglist) {
-    taglist = src->icy_taglist;
-    set_taglist = TRUE;
-  } else {
-    taglist = gst_tag_list_new ();
-  }
+  tags = g_strsplit (data, "';", 0);
 
   for (i = 0; tags[i]; i++) {
     if (!g_ascii_strncasecmp (tags[i], "StreamTitle=", 12)) {
       g_free (src->iradio_title);
       src->iradio_title = gst_gnomevfssrc_unicodify (tags[i] + 13);
       if (src->iradio_title) {
-        GST_DEBUG_OBJECT (src, "sending notification on icecast title");
+        GST_DEBUG ("sending notification on icecast title");
         g_object_notify (G_OBJECT (src), "iradio-title");
-        gst_tag_list_add (taglist, GST_TAG_MERGE_REPLACE, GST_TAG_TITLE,
-            src->iradio_title, NULL);
-        set_taglist = TRUE;
       } else
         g_print ("Unable to convert icecast title \"%s\" to UTF-8!\n",
             tags[i] + 13);
@@ -1080,11 +925,8 @@ gst_gnomevfssrc_get_icy_metadata (GstGnomeVFSSrc * src)
       g_free (src->iradio_url);
       src->iradio_url = gst_gnomevfssrc_unicodify (tags[i] + 11);
       if (src->iradio_url) {
-        GST_DEBUG_OBJECT (src, "sending notification on icecast url");
+        GST_DEBUG ("sending notification on icecast url");
         g_object_notify (G_OBJECT (src), "iradio-url");
-        gst_tag_list_add (taglist, GST_TAG_MERGE_REPLACE, GST_TAG_LOCATION,
-            src->iradio_url, NULL);
-        set_taglist = TRUE;
       } else
         g_print ("Unable to convert icecast url \"%s\" to UTF-8!\n",
             tags[i] + 11);
@@ -1092,10 +934,6 @@ gst_gnomevfssrc_get_icy_metadata (GstGnomeVFSSrc * src)
   }
 
   g_strfreev (tags);
-  if (set_taglist)
-    src->icy_taglist = taglist;
-  else
-    gst_tag_list_free (taglist);
 }
 
 /* end of icecast/audiocast metadata extraction support code */
@@ -1114,54 +952,37 @@ gst_gnomevfssrc_get (GstPad * pad)
   GstBuffer *buf;
   GnomeVFSFileSize readbytes;
   guint8 *data;
-  GstEvent *event;
 
   g_return_val_if_fail (pad != NULL, NULL);
   src = GST_GNOMEVFSSRC (gst_pad_get_parent (pad));
   g_return_val_if_fail (GST_FLAG_IS_SET (src, GST_GNOMEVFSSRC_OPEN), NULL);
 
   /* deal with EOF state */
-  if ((src->curoffset >= src->size) && (src->size != 0) && !src->new_seek) {
+  if ((src->curoffset >= src->size) && (src->size != 0)) {
     gst_element_set_eos (GST_ELEMENT (src));
-    GST_DEBUG_OBJECT (src, "Returning EOS");
     return GST_DATA (gst_event_new (GST_EVENT_EOS));
   }
 
-  /* grab tags from audiocast thread */
-  audiocast_do_notifications (src);
-
-  /* deal with tag list */
-  if (src->icy_taglist) {
-    gst_element_found_tags (GST_ELEMENT (src), src->icy_taglist);
-    event = gst_event_new_tag (src->icy_taglist);
-
-    gst_object_ref (GST_OBJECT (src));
-    event->src = GST_OBJECT (src);
-    src->icy_taglist = NULL;
-    return GST_DATA (event);
-  }
-
   /* create the buffer */
   /* FIXME: should eventually use a bufferpool for this */
   buf = gst_buffer_new ();
   g_return_val_if_fail (buf, NULL);
 
+  audiocast_do_notifications (src);
+
   if (src->iradio_mode && src->icy_metaint > 0) {
     GST_BUFFER_DATA (buf) = g_malloc0 (src->icy_metaint);
     data = GST_BUFFER_DATA (buf);
     g_return_val_if_fail (GST_BUFFER_DATA (buf) != NULL, NULL);
 
     GST_BUFFER_SIZE (buf) = 0;
-    GST_DEBUG_OBJECT (src, "doing read: icy_count: %" G_GINT64_FORMAT,
-        src->icy_count);
-    result =
-        gnome_vfs_read (src->handle, data, src->icy_metaint - src->icy_count,
-        &readbytes);
+    GST_DEBUG ("doing read: icy_count: %" G_GINT64_FORMAT, src->icy_count);
+    result = gnome_vfs_read (src->handle, data,
+        src->icy_metaint - src->icy_count, &readbytes);
 
     /* EOS? */
     if (readbytes == 0) {
       gst_buffer_unref (buf);
-      GST_DEBUG_OBJECT (src, "Returning EOS");
       gst_element_set_eos (GST_ELEMENT (src));
       return GST_DATA (gst_event_new (GST_EVENT_EOS));
     }
@@ -1173,7 +994,6 @@ gst_gnomevfssrc_get (GstPad * pad)
     src->curoffset += readbytes;
 
     if (src->icy_count == src->icy_metaint) {
-      /* we'll push the taglist through next time around */
       gst_gnomevfssrc_get_icy_metadata (src);
       src->icy_count = 0;
     }
@@ -1187,7 +1007,7 @@ gst_gnomevfssrc_get (GstPad * pad)
 
       src->need_flush = FALSE;
       gst_buffer_unref (buf);
-      GST_DEBUG_OBJECT (src, "gnomevfssrc sending flush");
+      GST_DEBUG ("gnomevfssrc sending flush");
       return GST_DATA (event);
     }
 
@@ -1195,9 +1015,9 @@ gst_gnomevfssrc_get (GstPad * pad)
       GstEvent *event;
 
       gst_buffer_unref (buf);
-      GST_DEBUG_OBJECT (src, "new seek %" G_GINT64_FORMAT, src->curoffset);
+      GST_DEBUG ("new seek %" G_GINT64_FORMAT, src->curoffset);
       src->new_seek = FALSE;
-      GST_DEBUG_OBJECT (src, "gnomevfssrc sending discont");
+      GST_DEBUG ("gnomevfssrc sending discont");
       event =
           gst_event_new_discontinuous (FALSE, GST_FORMAT_BYTES, src->curoffset,
           NULL);
@@ -1207,14 +1027,14 @@ gst_gnomevfssrc_get (GstPad * pad)
     result = gnome_vfs_read (src->handle, GST_BUFFER_DATA (buf),
         src->bytes_per_read, &readbytes);
 
-    GST_DEBUG_OBJECT (src,
-        "read: %s, readbytes: %" G_GINT64_FORMAT " @ %" G_GINT64_FORMAT,
-        gnome_vfs_result_to_string (result), readbytes, src->curoffset);
+    GST_DEBUG ("read: %s, readbytes: %" G_GINT64_FORMAT,
+        gnome_vfs_result_to_string (result), readbytes);
     /* deal with EOS */
     if (readbytes == 0) {
       gst_buffer_unref (buf);
-      GST_DEBUG_OBJECT (src, "Returning EOS");
+
       gst_element_set_eos (GST_ELEMENT (src));
+
       return GST_DATA (gst_event_new (GST_EVENT_EOS));
     }
 
@@ -1238,66 +1058,56 @@ gst_gnomevfssrc_open_file (GstGnomeVFSSrc * src)
 
   g_return_val_if_fail (!GST_FLAG_IS_SET (src, GST_GNOMEVFSSRC_OPEN), FALSE);
 
+  if (src->filename) {
+    /* create the uri */
+    src->uri = gnome_vfs_uri_new (src->filename);
+    if (!src->uri) {
+      GST_ELEMENT_ERROR (src, RESOURCE, OPEN_READ,
+          (_("Could not open vfs file \"%s\" for reading."), src->filename),
+          GST_ERROR_SYSTEM);
+      return FALSE;
+    }
+  }
+
   if (!audiocast_init (src))
     return FALSE;
 
-  if (src->iradio_mode)
-    gst_gnomevfssrc_push_callbacks (src);
+  gst_gnomevfssrc_push_callbacks (src);
 
-  if (src->uri != NULL) {
-    result = gnome_vfs_open_uri (&(src->handle), src->uri,
-        GNOME_VFS_OPEN_READ | GNOME_VFS_OPEN_RANDOM);
+  if (src->filename)
+    result = gnome_vfs_open_uri (&(src->handle), src->uri, GNOME_VFS_OPEN_READ);
+  else
+    result = GNOME_VFS_OK;
+  if (result != GNOME_VFS_OK) {
+    char *escaped;
 
-    if (result == GNOME_VFS_ERROR_INVALID_OPEN_MODE ||
-        result == GNOME_VFS_ERROR_NOT_SUPPORTED) {
+    gst_gnomevfssrc_pop_callbacks (src);
+    audiocast_thread_kill (src);
 
-      /* seeking might not be supported, try without it */
-      result = gnome_vfs_open_uri (&(src->handle), src->uri,
-          GNOME_VFS_OPEN_READ);
-    }
-
-    if (result != GNOME_VFS_OK) {
-      gchar *filename = gnome_vfs_uri_to_string (src->uri,
-          GNOME_VFS_URI_HIDE_PASSWORD);
-
-      if (src->iradio_mode)
-        gst_gnomevfssrc_pop_callbacks (src);
-      audiocast_thread_kill (src);
-
-      if (result == GNOME_VFS_ERROR_NOT_FOUND) {
-        GST_ELEMENT_ERROR (src, RESOURCE, NOT_FOUND,
-            (_("Could not open vfs file \"%s\" for reading."), filename),
-            (gnome_vfs_result_to_string (result)));
-      } else {
-        GST_ELEMENT_ERROR (src, RESOURCE, OPEN_READ,
-            (_("Could not open vfs file \"%s\" for reading."), filename),
-            (gnome_vfs_result_to_string (result)));
-      }
-      g_free (filename);
-      return FALSE;
-    }
-    src->own_handle = TRUE;
-  } else if (!src->handle) {
+    escaped = gnome_vfs_unescape_string_for_display (src->filename);
     GST_ELEMENT_ERROR (src, RESOURCE, OPEN_READ,
-        (_("No filename given.")), (NULL));
+        (_("Could not open vfs file \"%s\" for reading."), escaped),
+        (gnome_vfs_result_to_string (result)));
+    g_free (escaped);
     return FALSE;
-  } else {
-    src->own_handle = FALSE;
   }
 
   info = gnome_vfs_file_info_new ();
-  if ((result = gnome_vfs_get_file_info_from_handle (src->handle,
-              info, GNOME_VFS_FILE_INFO_DEFAULT))
+  if (gnome_vfs_get_file_info_from_handle (src->handle, info,
+          GNOME_VFS_FILE_INFO_DEFAULT)
       == GNOME_VFS_OK) {
     if (info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SIZE)
       src->size = info->size;
   } else
-    GST_DEBUG_OBJECT (src, "getting info failed: %s",
-        gnome_vfs_result_to_string (result));
+    GST_DEBUG ("getting info failed: %s", gnome_vfs_result_to_string (result));
 
   gnome_vfs_file_info_unref (info);
 
-  GST_DEBUG_OBJECT (src, "size %" G_GINT64_FORMAT, src->size);
+  GST_DEBUG ("size %" G_GINT64_FORMAT, src->size);
+
+  audiocast_do_notifications (src);
+
+  GST_DEBUG ("open result: %s", gnome_vfs_result_to_string (result));
 
   if (gnome_vfs_seek (src->handle, GNOME_VFS_SEEK_CURRENT, 0)
       == GNOME_VFS_OK) {
@@ -1316,13 +1126,13 @@ gst_gnomevfssrc_close_file (GstGnomeVFSSrc * src)
 {
   g_return_if_fail (GST_FLAG_IS_SET (src, GST_GNOMEVFSSRC_OPEN));
 
-  if (src->iradio_mode)
-    gst_gnomevfssrc_pop_callbacks (src);
+  gst_gnomevfssrc_pop_callbacks (src);
   audiocast_thread_kill (src);
 
-  if (src->own_handle) {
+  if (src->filename) {
     gnome_vfs_close (src->handle);
-    src->handle = NULL;
+
+    gnome_vfs_uri_unref (src->uri);
   }
   src->size = 0;
   src->curoffset = 0;
@@ -1367,7 +1177,7 @@ gst_gnomevfssrc_srcpad_query (GstPad * pad, GstQueryType type,
 
   switch (type) {
     case GST_QUERY_TOTAL:
-      if (*format != GST_FORMAT_BYTES || src->size == 0) {
+      if (*format != GST_FORMAT_BYTES) {
         return FALSE;
       }
       *value = src->size;
@@ -1416,8 +1226,6 @@ gst_gnomevfssrc_srcpad_event (GstPad * pad, GstEvent * event)
           desired_offset = src->curoffset + GST_EVENT_SEEK_OFFSET (event);
           break;
         case GST_SEEK_METHOD_END:
-          if (src->size == 0)
-            return FALSE;
           desired_offset = src->size - ABS (GST_EVENT_SEEK_OFFSET (event));
           break;
         default:
@@ -1428,8 +1236,7 @@ gst_gnomevfssrc_srcpad_event (GstPad * pad, GstEvent * event)
 
       result = gnome_vfs_seek (src->handle,
           GNOME_VFS_SEEK_START, desired_offset);
-      GST_DEBUG_OBJECT (src, "new_seek to %" G_GINT64_FORMAT ": %s",
-          desired_offset, gnome_vfs_result_to_string (result));
+      GST_DEBUG ("new_seek: %s", gnome_vfs_result_to_string (result));
 
       if (result != GNOME_VFS_OK) {
         gst_event_unref (event);
