@@ -42,8 +42,8 @@ enum
 
 enum
 {
-  ARG_0
-      /* FILL ME */
+  ARG_0,
+  /* FILL ME */
 };
 
 static void gst_gsmdec_base_init (gpointer g_class);
@@ -51,6 +51,8 @@ static void gst_gsmdec_class_init (GstGSMDec * klass);
 static void gst_gsmdec_init (GstGSMDec * gsmdec);
 
 static void gst_gsmdec_chain (GstPad * pad, GstData * _data);
+static GstPadLinkReturn gst_gsmdec_sinkconnect (GstPad * pad,
+    const GstCaps * caps);
 
 static GstElementClass *parent_class = NULL;
 
@@ -73,7 +75,6 @@ gst_gsmdec_get_type (void)
       0,
       (GInstanceInitFunc) gst_gsmdec_init,
     };
-
     gsmdec_type =
         g_type_register_static (GST_TYPE_ELEMENT, "GstGSMDec", &gsmdec_info, 0);
   }
@@ -84,7 +85,8 @@ static GstStaticPadTemplate gsmdec_sink_template =
 GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
     GST_PAD_ALWAYS,
-    GST_STATIC_CAPS ("audio/x-gsm, " "rate = (int) 8000, " "channels = (int) 1")
+    GST_STATIC_CAPS ("audio/x-gsm, "
+        "rate = (int) [ 1000, 48000 ], " "channels = (int) 1")
     );
 
 static GstStaticPadTemplate gsmdec_src_template =
@@ -95,7 +97,8 @@ GST_STATIC_PAD_TEMPLATE ("src",
         "endianness = (int) BYTE_ORDER, "
         "signed = (boolean) true, "
         "width = (int) 16, "
-        "depth = (int) 16, " "rate = (int) 8000, " "channels = (int) 1")
+        "depth = (int) 16, "
+        "rate = (int) [ 1000, 48000 ], " "channels = (int) 1")
     );
 
 static void
@@ -129,8 +132,9 @@ gst_gsmdec_init (GstGSMDec * gsmdec)
   gsmdec->sinkpad =
       gst_pad_new_from_template (gst_static_pad_template_get
       (&gsmdec_sink_template), "sink");
-  gst_pad_set_chain_function (gsmdec->sinkpad, gst_gsmdec_chain);
   gst_element_add_pad (GST_ELEMENT (gsmdec), gsmdec->sinkpad);
+  gst_pad_set_chain_function (gsmdec->sinkpad, gst_gsmdec_chain);
+  gst_pad_set_link_function (gsmdec->sinkpad, gst_gsmdec_sinkconnect);
 
   gsmdec->srcpad =
       gst_pad_new_from_template (gst_static_pad_template_get
@@ -139,93 +143,89 @@ gst_gsmdec_init (GstGSMDec * gsmdec)
 
   gsmdec->state = gsm_create ();
   gsmdec->bufsize = 0;
-  gsmdec->next_ts = 0;
-  gsmdec->next_of = 0;
+}
+
+static GstPadLinkReturn
+gst_gsmdec_sinkconnect (GstPad * pad, const GstCaps * caps)
+{
+  GstGSMDec *gsmdec;
+  gint rate;
+  GstStructure *structure;
+
+  gsmdec = GST_GSMDEC (gst_pad_get_parent (pad));
+
+  structure = gst_caps_get_structure (caps, 0);
+  gst_structure_get_int (structure, "rate", &rate);
+
+  if (gst_pad_try_set_caps (gsmdec->srcpad,
+          gst_caps_new_simple ("audio/x-raw-int",
+              "endianness", G_TYPE_INT, G_BYTE_ORDER,
+              "signed", G_TYPE_BOOLEAN, TRUE,
+              "width", G_TYPE_INT, 16,
+              "depth", G_TYPE_INT, 16,
+              "rate", G_TYPE_INT, rate, "channels", G_TYPE_INT, 1, NULL)) > 0) {
+    return GST_PAD_LINK_OK;
+  }
+  return GST_PAD_LINK_REFUSED;
 }
 
 static void
 gst_gsmdec_chain (GstPad * pad, GstData * _data)
 {
+  GstBuffer *buf = GST_BUFFER (_data);
   GstGSMDec *gsmdec;
+  gsm_byte *data;
+  guint size;
 
   g_return_if_fail (pad != NULL);
   g_return_if_fail (GST_IS_PAD (pad));
-  g_return_if_fail (_data != NULL);
+  g_return_if_fail (buf != NULL);
+  /*g_return_if_fail(GST_IS_BUFFER(buf)); */
 
   gsmdec = GST_GSMDEC (gst_pad_get_parent (pad));
 
-  if (GST_IS_EVENT (_data)) {
-    GstEvent *event = GST_EVENT (_data);
+  data = (gsm_byte *) GST_BUFFER_DATA (buf);
+  size = GST_BUFFER_SIZE (buf);
 
-    switch (GST_EVENT_TYPE (event)) {
-      case GST_EVENT_EOS:{
-        gst_element_set_eos (GST_ELEMENT (gsmdec));
-        gst_pad_push (gsmdec->srcpad, _data);
-        break;
-      }
-      case GST_EVENT_DISCONTINUOUS:{
-        /* drop the discontinuity */
-        break;
-      }
-      default:{
-        gst_pad_event_default (pad, event);
-        break;
-      }
-    }
-    return;
-  } else if (GST_IS_BUFFER (_data)) {
-    GstBuffer *buf = GST_BUFFER (_data);
-    gsm_byte *data = (gsm_byte *) GST_BUFFER_DATA (buf);
-    guint size = GST_BUFFER_SIZE (buf);
+  if (gsmdec->bufsize && (gsmdec->bufsize + size >= 33)) {
+    GstBuffer *outbuf;
 
-    if (gsmdec->bufsize && (gsmdec->bufsize + size >= 33)) {
-      GstBuffer *outbuf;
+    memcpy (gsmdec->buffer + gsmdec->bufsize, data,
+        (33 - gsmdec->bufsize) * sizeof (gsm_byte));
 
-      memcpy (gsmdec->buffer + gsmdec->bufsize, data,
-          (33 - gsmdec->bufsize) * sizeof (gsm_byte));
+    outbuf = gst_buffer_new ();
+    GST_BUFFER_DATA (outbuf) = g_malloc (160 * sizeof (gsm_signal));
+    GST_BUFFER_SIZE (outbuf) = 160 * sizeof (gsm_signal);
 
-      outbuf = gst_buffer_new_and_alloc (160 * sizeof (gsm_signal));
-      GST_BUFFER_TIMESTAMP (outbuf) = gsmdec->next_ts;
-      GST_BUFFER_DURATION (outbuf) = 20 * GST_MSECOND;
-      GST_BUFFER_OFFSET (outbuf) = gsmdec->next_of;
-      GST_BUFFER_OFFSET_END (outbuf) = gsmdec->next_of + 160 - 1;
-      gsmdec->next_ts += 20 * GST_MSECOND;
-      gsmdec->next_of += 160;
+    gsm_decode (gsmdec->state, gsmdec->buffer,
+        (gsm_signal *) GST_BUFFER_DATA (outbuf));
 
-      gsm_decode (gsmdec->state, gsmdec->buffer,
-          (gsm_signal *) GST_BUFFER_DATA (outbuf));
+    gst_pad_push (gsmdec->srcpad, GST_DATA (outbuf));
 
-      gst_pad_push (gsmdec->srcpad, GST_DATA (outbuf));
-
-      size -= (33 - gsmdec->bufsize);
-      data += (33 - gsmdec->bufsize);
-      gsmdec->bufsize = 0;
-    }
-
-    while (size >= 33) {
-      GstBuffer *outbuf;
-
-      outbuf = gst_buffer_new_and_alloc (160 * sizeof (gsm_signal));
-      GST_BUFFER_TIMESTAMP (outbuf) = gsmdec->next_ts;
-      GST_BUFFER_DURATION (outbuf) = 20 * GST_MSECOND;
-      GST_BUFFER_OFFSET (outbuf) = gsmdec->next_of;
-      GST_BUFFER_OFFSET_END (outbuf) = gsmdec->next_of + 160 - 1;
-      gsmdec->next_ts += 20 * GST_MSECOND;
-      gsmdec->next_of += 160;
-
-      gsm_decode (gsmdec->state, data, (gsm_signal *) GST_BUFFER_DATA (outbuf));
-      gst_pad_push (gsmdec->srcpad, GST_DATA (outbuf));
-
-      size -= 33;
-      data += 33;
-    }
-
-    if (size) {
-      memcpy (gsmdec->buffer + gsmdec->bufsize, data, size * sizeof (gsm_byte));
-      gsmdec->bufsize += size;
-    }
-
-    gst_buffer_unref (buf);
-    return;
+    size -= (33 - gsmdec->bufsize);
+    data += (33 - gsmdec->bufsize);
+    gsmdec->bufsize = 0;
   }
+
+  while (size >= 33) {
+    GstBuffer *outbuf;
+
+    outbuf = gst_buffer_new ();
+    GST_BUFFER_DATA (outbuf) = g_malloc (160 * sizeof (gsm_signal));
+    GST_BUFFER_SIZE (outbuf) = 160 * sizeof (gsm_signal);
+
+    gsm_decode (gsmdec->state, data, (gsm_signal *) GST_BUFFER_DATA (outbuf));
+
+    gst_pad_push (gsmdec->srcpad, GST_DATA (outbuf));
+
+    size -= 33;
+    data += 33;
+  }
+
+  if (size) {
+    memcpy (gsmdec->buffer + gsmdec->bufsize, data, size * sizeof (gsm_byte));
+    gsmdec->bufsize += size;
+  }
+
+  gst_buffer_unref (buf);
 }
