@@ -48,7 +48,8 @@ typedef enum
   GST_HERMES_COLORSPACE_RGB32_I420,
   GST_HERMES_COLORSPACE_RGB32_YV12,
   GST_HERMES_COLORSPACE_420_SWAP,
-} GstColorSpaceConverterType;
+}
+GstColorSpaceConverterType;
 
 struct _GstHermesColorspace
 {
@@ -85,7 +86,8 @@ typedef struct _GstHermesColorspaceFormat
 {
   GstStaticCaps caps;
 
-} GstHermesColorspaceFormat;
+}
+GstHermesColorspaceFormat;
 
 static GstHermesColorspaceFormat gst_hermes_colorspace_formats[] = {
   {GST_STATIC_CAPS (GST_VIDEO_CAPS_xRGB)},
@@ -469,6 +471,7 @@ gst_hermes_colorspace_get_type (void)
       0,
       (GInstanceInitFunc) gst_hermes_colorspace_init,
     };
+
     colorspace_type =
         g_type_register_static (GST_TYPE_ELEMENT, "GstHermesColorspace",
         &colorspace_info, 0);
@@ -653,7 +656,7 @@ plugin_init (GstPlugin * plugin)
   hermes_res = Hermes_Init ();
   g_return_val_if_fail (hermes_res != 0, FALSE);
 
-  if (!gst_element_register (plugin, "hermescolorspace", GST_RANK_PRIMARY,
+  if (!gst_element_register (plugin, "hermescolorspace", GST_RANK_PRIMARY - 2,
           GST_TYPE_COLORSPACE))
     return FALSE;
 
