@@ -22,7 +22,6 @@
 #define __GST_MPEG2DEC_H__
 
 
-#include <config.h>
 #include <gst/gst.h>
 #include <mpeg2.h>
 
@@ -48,15 +47,16 @@ typedef struct _GstMpeg2decClass GstMpeg2decClass;
 typedef enum
 {
   MPEG2DEC_FORMAT_NONE,
+  MPEG2DEC_FORMAT_I422,
   MPEG2DEC_FORMAT_I420,
-  MPEG2DEC_FORMAT_YV12,
+  MPEG2DEC_FORMAT_YV12
 } Mpeg2decFormat;
 
 typedef enum 
 {
   MPEG2DEC_DISC_NONE 		= 0,
   MPEG2DEC_DISC_NEW_PICTURE,
-  MPEG2DEC_DISC_NEW_KEYFRAME,
+  MPEG2DEC_DISC_NEW_KEYFRAME
 } DiscontState;
 
 struct _GstMpeg2dec {
@@ -66,7 +66,6 @@ struct _GstMpeg2dec {
   GstPad 	*sinkpad,
   		*srcpad,
   		*userdatapad;
-  GstBufferPool *peerpool;
 
   mpeg2dec_t 	*decoder;
   gboolean	 closed;
@@ -89,7 +88,6 @@ struct _GstMpeg2dec {
   gint64	 frame_period;
   gboolean	 need_sequence;
 
-  GstCaps	*streaminfo;
   GstEvent	*pending_event;
 
   GstIndex	*index;
