@@ -19,8 +19,8 @@
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
- */ 
- 
+ */
+
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -28,14 +28,14 @@
 #include <math.h>
 #include <string.h>
 #include <gst/gst.h>
-#include "gsteffectv.h"
+#include <gstvideofilter.h>
 
 #define GST_TYPE_VERTIGOTV \
   (gst_vertigotv_get_type())
 #define GST_VERTIGOTV(obj) \
   (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_VERTIGOTV,GstVertigoTV))
 #define GST_VERTIGOTV_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_ULAW,GstVertigoTV))
+  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_VERTIGOTV,GstVertigoTVClass))
 #define GST_IS_VERTIGOTV(obj) \
   (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_VERTIGOTV))
 #define GST_IS_VERTIGOTV_CLASS(obj) \
@@ -46,9 +46,7 @@ typedef struct _GstVertigoTVClass GstVertigoTVClass;
 
 struct _GstVertigoTV
 {
-  GstElement element;
-
-  GstPad *sinkpad, *srcpad;
+  GstVideofilter videofilter;
 
   gint width, height;
   guint32 *buffer;
@@ -58,28 +56,15 @@ struct _GstVertigoTV
   gdouble phase;
   gdouble phase_increment;
   gdouble zoomrate;
-
 };
 
 struct _GstVertigoTVClass
 {
-  GstElementClass parent_class;
+  GstVideofilterClass parent_class;
 
-  void (*reset) (GstElement *element);
+  void (*reset) (GstElement * element);
 };
 
-/* elementfactory information */
-GstElementDetails gst_vertigotv_details = {
-  "VertigoTV",
-  "Filter/Video/Effect",
-  "LGPL",
-  "A loopback alpha blending effector with rotating and scaling",
-  VERSION,
-  "Wim Taymans <wim.taymans@chello.be>",
-  "(C) 2001 FUKUCHI Kentarou",
-};
-
-
 /* Filter signals and args */
 enum
 {
@@ -95,28 +80,32 @@ enum
   ARG_ZOOM_SPEED,
 };
 
-static void 	gst_vertigotv_class_init 	(GstVertigoTVClass * klass);
-static void 	gst_vertigotv_init 		(GstVertigoTV * filter);
+static void gst_vertigotv_base_init (gpointer g_class);
+static void gst_vertigotv_class_init (GstVertigoTVClass * klass,
+    gpointer class_data);
+static void gst_vertigotv_init (GTypeInstance * instance, gpointer g_class);
+static void gst_vertigotv_setup (GstVideofilter * videofilter);
 
-static void 	gst_vertigotv_reset_handler 	(GstElement *element);
+static void gst_vertigotv_reset_handler (GstElement * element);
 
-static void 	gst_vertigotv_set_property 	(GObject * object, guint prop_id,
-					  	 const GValue * value, GParamSpec * pspec);
-static void 	gst_vertigotv_get_property 	(GObject * object, guint prop_id,
-					  	 GValue * value, GParamSpec * pspec);
+static void gst_vertigotv_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec);
+static void gst_vertigotv_get_property (GObject * object, guint prop_id,
+    GValue * value, GParamSpec * pspec);
+static void gst_vertigotv_rgb32 (GstVideofilter * videofilter, void *d,
+    void *s);
 
-static void 	gst_vertigotv_chain 		(GstPad * pad, GstData *_data);
-
-static GstElementClass *parent_class = NULL;
 static guint gst_vertigotv_signals[LAST_SIGNAL] = { 0 };
 
-GType gst_vertigotv_get_type (void)
+GType
+gst_vertigotv_get_type (void)
 {
   static GType vertigotv_type = 0;
 
   if (!vertigotv_type) {
     static const GTypeInfo vertigotv_info = {
-      sizeof (GstVertigoTVClass), NULL,
+      sizeof (GstVertigoTVClass),
+      gst_vertigotv_base_init,
       NULL,
       (GClassInitFunc) gst_vertigotv_class_init,
       NULL,
@@ -126,46 +115,75 @@ GType gst_vertigotv_get_type (void)
       (GInstanceInitFunc) gst_vertigotv_init,
     };
 
-    vertigotv_type = g_type_register_static (GST_TYPE_ELEMENT, "GstVertigoTV", &vertigotv_info, 0);
+    vertigotv_type =
+        g_type_register_static (GST_TYPE_VIDEOFILTER, "GstVertigoTV",
+        &vertigotv_info, 0);
   }
   return vertigotv_type;
 }
 
+static GstVideofilterFormat gst_vertigotv_formats[] = {
+  {"RGB ", 32, gst_vertigotv_rgb32, 24, G_BIG_ENDIAN, 0x0000ff00, 0x00ff0000,
+      0xff000000}
+};
+
 static void
-gst_vertigotv_class_init (GstVertigoTVClass * klass)
+gst_vertigotv_base_init (gpointer g_class)
 {
-  GObjectClass *gobject_class;
-  GstElementClass *gstelement_class;
+  /* elementfactory information */
+  static GstElementDetails vertigotv_details = GST_ELEMENT_DETAILS ("VertigoTV",
+      "Filter/Effect/Video",
+      "A loopback alpha blending effector with rotating and scaling",
+      "Wim Taymans <wim.taymans@chello.be>");
+  GstElementClass *element_class = GST_ELEMENT_CLASS (g_class);
+  GstVideofilterClass *videofilter_class = GST_VIDEOFILTER_CLASS (g_class);
+  int i;
 
-  gobject_class = (GObjectClass *) klass;
-  gstelement_class = (GstElementClass *) klass;
+  gst_element_class_set_details (element_class, &vertigotv_details);
 
-  parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
+  for (i = 0; i < G_N_ELEMENTS (gst_vertigotv_formats); i++) {
+    gst_videofilter_class_add_format (videofilter_class,
+        gst_vertigotv_formats + i);
+  }
 
-  gst_vertigotv_signals[RESET_SIGNAL] =
-    g_signal_new ("reset_parms",
-                  G_TYPE_FROM_CLASS (klass),
-                  G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-                  G_STRUCT_OFFSET (GstVertigoTVClass, reset),
-                  NULL, NULL,
-                  g_cclosure_marshal_VOID__VOID,
-                  G_TYPE_NONE, 0);
-
-  klass->reset = gst_vertigotv_reset_handler;
-       
-  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_SPEED,
-    g_param_spec_float ("speed","Speed","Control the speed of movement",
-                        0.01, 100.0, 0.02, G_PARAM_READWRITE));
-  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_ZOOM_SPEED,
-    g_param_spec_float ("zoom_speed","Zoom Speed","Control the rate of zooming",
-                        1.01, 1.1, 1.01, G_PARAM_READWRITE));
-
-  gobject_class->set_property = gst_vertigotv_set_property;
-  gobject_class->get_property = gst_vertigotv_get_property;
+  gst_videofilter_class_add_pad_templates (GST_VIDEOFILTER_CLASS (g_class));
 }
 
 static void
-gst_vertigotv_reset_handler (GstElement *element)
+gst_vertigotv_class_init (GstVertigoTVClass * klass, gpointer class_data)
+{
+  GObjectClass *gobject_class;
+  GstElementClass *gstelement_class;
+  GstVideofilterClass *videofilter_class;
+
+  gobject_class = (GObjectClass *) klass;
+  gstelement_class = (GstElementClass *) klass;
+  videofilter_class = GST_VIDEOFILTER_CLASS (klass);
+
+  gst_vertigotv_signals[RESET_SIGNAL] =
+      g_signal_new ("reset-parms",
+      G_TYPE_FROM_CLASS (klass),
+      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+      G_STRUCT_OFFSET (GstVertigoTVClass, reset),
+      NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
+
+  klass->reset = gst_vertigotv_reset_handler;
+
+  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_SPEED,
+      g_param_spec_float ("speed", "Speed", "Control the speed of movement",
+          0.01, 100.0, 0.02, G_PARAM_READWRITE));
+  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_ZOOM_SPEED,
+      g_param_spec_float ("zoom_speed", "Zoom Speed",
+          "Control the rate of zooming", 1.01, 1.1, 1.01, G_PARAM_READWRITE));
+
+  gobject_class->set_property = gst_vertigotv_set_property;
+  gobject_class->get_property = gst_vertigotv_get_property;
+
+  videofilter_class->setup = gst_vertigotv_setup;
+}
+
+static void
+gst_vertigotv_reset_handler (GstElement * element)
 {
   GstVertigoTV *filter = GST_VERTIGOTV (element);
 
@@ -174,44 +192,35 @@ gst_vertigotv_reset_handler (GstElement *element)
   filter->zoomrate = 1.01;
 }
 
-
-static GstPadLinkReturn
-gst_vertigotv_sinkconnect (GstPad * pad, GstCaps * caps)
+static void
+gst_vertigotv_setup (GstVideofilter * videofilter)
 {
   GstVertigoTV *filter;
   gint area;
+  int width = gst_videofilter_get_input_width (videofilter);
+  int height = gst_videofilter_get_input_height (videofilter);
 
-  filter = GST_VERTIGOTV (gst_pad_get_parent (pad));
+  g_return_if_fail (GST_IS_VERTIGOTV (videofilter));
+  filter = GST_VERTIGOTV (videofilter);
 
-  if (!GST_CAPS_IS_FIXED (caps))
-    return GST_PAD_LINK_DELAYED;
+  filter->width = width;
+  filter->height = height;
 
-  gst_caps_get_int (caps, "width", &filter->width);
-  gst_caps_get_int (caps, "height", &filter->height);
-
-  area = filter->width * filter->height;
+  area = width * height;
 
   g_free (filter->buffer);
-  filter->buffer = (guint32 *) g_malloc (area * 2 * sizeof(guint32));
+  filter->buffer = (guint32 *) g_malloc (area * 2 * sizeof (guint32));
 
-  bzero (filter->buffer, area * 2 * sizeof(guint32));
+  memset (filter->buffer, 0, area * 2 * sizeof (guint32));
   filter->current_buffer = filter->buffer;
   filter->alt_buffer = filter->buffer + area;
   filter->phase = 0;
-
-  return gst_pad_try_set_caps (filter->srcpad, gst_caps_ref (caps));
 }
 
 static void
-gst_vertigotv_init (GstVertigoTV * filter)
+gst_vertigotv_init (GTypeInstance * instance, gpointer g_class)
 {
-  filter->sinkpad = gst_pad_new_from_template (gst_effectv_sink_factory (), "sink");
-  gst_pad_set_chain_function (filter->sinkpad, gst_vertigotv_chain);
-  gst_pad_set_link_function (filter->sinkpad, gst_vertigotv_sinkconnect);
-  gst_element_add_pad (GST_ELEMENT (filter), filter->sinkpad);
-
-  filter->srcpad = gst_pad_new_from_template (gst_effectv_src_factory (), "src");
-  gst_element_add_pad (GST_ELEMENT (filter), filter->srcpad);
+  GstVertigoTV *filter = GST_VERTIGOTV (instance);
 
   filter->buffer = NULL;
   filter->phase = 0.0;
@@ -219,36 +228,40 @@ gst_vertigotv_init (GstVertigoTV * filter)
   filter->zoomrate = 1.01;
 }
 
-static void 
-gst_vertigotv_set_parms (GstVertigoTV *filter)
+static void
+gst_vertigotv_set_parms (GstVertigoTV * filter)
 {
   double vx, vy;
   double t;
   double x, y;
   double dizz;
 
-  dizz = sin (filter->phase) * 10 + sin (filter->phase*1.9+5) * 5;
+  dizz = sin (filter->phase) * 10 + sin (filter->phase * 1.9 + 5) * 5;
 
   x = filter->width / 2;
   y = filter->height / 2;
 
-  t = (x*x + y*y) * filter->zoomrate;
+  t = (x * x + y * y) * filter->zoomrate;
 
   if (filter->width > filter->height) {
     if (dizz >= 0) {
-      if (dizz > x) dizz = x;
-    	vx = (x * (x - dizz) + y * y) / t;
+      if (dizz > x)
+        dizz = x;
+      vx = (x * (x - dizz) + y * y) / t;
     } else {
-      if (dizz < -x) dizz = -x;
+      if (dizz < -x)
+        dizz = -x;
       vx = (x * (x + dizz) + y * y) / t;
     }
     vy = (dizz * y) / t;
   } else {
     if (dizz >= 0) {
-      if (dizz > y) dizz = y;
+      if (dizz > y)
+        dizz = y;
       vx = (x * x + y * (y - dizz)) / t;
     } else {
-      if (dizz < -y) dizz = -y;
+      if (dizz < -y)
+        dizz = -y;
       vx = (x * x + y * (y + dizz)) / t;
     }
     vy = (dizz * x) / t;
@@ -259,16 +272,15 @@ gst_vertigotv_set_parms (GstVertigoTV *filter)
   filter->sy = (-vx * y - vy * x + y + sin (filter->phase * 6) * 2) * 65536;
 
   filter->phase += filter->phase_increment;
-  if (filter->phase > 5700000) filter->phase = 0;
+  if (filter->phase > 5700000)
+    filter->phase = 0;
 }
-	
+
 static void
-gst_vertigotv_chain (GstPad * pad, GstData *_data)
+gst_vertigotv_rgb32 (GstVideofilter * videofilter, void *d, void *s)
 {
-  GstBuffer *buf = GST_BUFFER (_data);
   GstVertigoTV *filter;
   guint32 *src, *dest;
-  GstBuffer *outbuf;
   guint32 *p;
   guint32 v;
   gint x, y;
@@ -276,19 +288,15 @@ gst_vertigotv_chain (GstPad * pad, GstData *_data)
   gint i;
   gint width, height, area;
 
-  filter = GST_VERTIGOTV (gst_pad_get_parent (pad));
+  filter = GST_VERTIGOTV (videofilter);
 
-  src = (guint32 *) GST_BUFFER_DATA (buf);
+  src = (guint32 *) s;
+  dest = (guint32 *) d;
 
   width = filter->width;
   height = filter->height;
   area = width * height;
 
-  outbuf = gst_buffer_new ();
-  GST_BUFFER_SIZE (outbuf) = area * sizeof(guint32);
-  dest = (guint32 *) GST_BUFFER_DATA (outbuf) = g_malloc (GST_BUFFER_SIZE (outbuf));
-  GST_BUFFER_TIMESTAMP (outbuf) = GST_BUFFER_TIMESTAMP (buf);
-  
   gst_vertigotv_set_parms (filter);
   p = filter->alt_buffer;
 
@@ -298,12 +306,14 @@ gst_vertigotv_chain (GstPad * pad, GstData *_data)
 
     for (x = width; x > 0; x--) {
       i = (oy >> 16) * width + (ox >> 16);
-      if (i < 0) i = 0;
-      if (i >= area) i = area;
-      
+      if (i < 0)
+        i = 0;
+      if (i >= area)
+        i = area;
+
       v = filter->current_buffer[i] & 0xfcfcff;
       v = (v * 3) + ((*src++) & 0xfcfcff);
-      
+
       *p++ = (v >> 2);
       ox += filter->dx;
       oy += filter->dy;
@@ -312,11 +322,7 @@ gst_vertigotv_chain (GstPad * pad, GstData *_data)
     filter->sy += filter->dx;
   }
 
-  memcpy(dest, filter->alt_buffer, area * sizeof(guint32));
-
-  gst_buffer_unref (buf);
-
-  gst_pad_push (filter->srcpad, GST_DATA (outbuf));
+  memcpy (dest, filter->alt_buffer, area * sizeof (guint32));
 
   p = filter->current_buffer;
   filter->current_buffer = filter->alt_buffer;
@@ -324,7 +330,8 @@ gst_vertigotv_chain (GstPad * pad, GstData *_data)
 }
 
 static void
-gst_vertigotv_set_property (GObject * object, guint prop_id, const GValue * value, GParamSpec * pspec)
+gst_vertigotv_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec)
 {
   GstVertigoTV *filter;
 
@@ -346,7 +353,8 @@ gst_vertigotv_set_property (GObject * object, guint prop_id, const GValue * valu
 }
 
 static void
-gst_vertigotv_get_property (GObject * object, guint prop_id, GValue * value, GParamSpec * pspec)
+gst_vertigotv_get_property (GObject * object, guint prop_id, GValue * value,
+    GParamSpec * pspec)
 {
   GstVertigoTV *filter;
 
