@@ -76,7 +76,7 @@ static GstStaticPadTemplate modplug_src_template_factory =
     GST_PAD_SRC,
     GST_PAD_ALWAYS,
     GST_STATIC_CAPS ("audio/x-raw-int, " "endianness = (int) BYTE_ORDER, " "signed = (boolean) TRUE, " "width = (int) 16, " "depth = (int) 16, " "rate = (int) { 8000, 11025, 22050, 44100 }, " /* FIXME? */
-        "channels = (int) [ 1, 2 ]; " "audio/x-raw-int, " "endianness = (int) BYTE_ORDER, " "signed = (boolean) FALSE, " "width = (int) 8, " "depth = (int) 8, " "rate = (int) { 8000, 11025, 22050, 44100 }, " /* FIXME? */
+        "channels = (int) [ 1, 2 ]; " "audio/x-raw-int, " "signed = (boolean) FALSE, " "width = (int) 8, " "depth = (int) 8, " "rate = (int) { 8000, 11025, 22050, 44100 }, "   /* FIXME? */
         "channels = (int) [ 1, 2 ]")
     );
 
@@ -91,7 +91,7 @@ enum
 {
   MODPLUG_STATE_NEED_TUNE = 1,
   MODPLUG_STATE_LOAD_TUNE = 2,
-  MODPLUG_STATE_PLAY_TUNE = 3
+  MODPLUG_STATE_PLAY_TUNE = 3,
 };
 
 static void gst_modplug_base_init (GstModPlugClass * klass);
@@ -133,7 +133,6 @@ gst_modplug_get_type (void)
       (GInstanceInitFunc) gst_modplug_init,
       NULL
     };
-
     modplug_type =
         g_type_register_static (GST_TYPE_ELEMENT, "GstModPlug", &modplug_info,
         (GTypeFlags) 0);
@@ -333,9 +332,6 @@ gst_modplug_src_query (GstPad * pad, GstQueryType type,
 
   modplug = GST_MODPLUG (gst_pad_get_parent (pad));
 
-  if (!modplug->mSoundFile)
-    return FALSE;
-
   switch (type) {
     case GST_QUERY_TOTAL:
       switch (*format) {
@@ -349,20 +345,15 @@ gst_modplug_src_query (GstPad * pad, GstQueryType type,
       break;
     case GST_QUERY_POSITION:
       switch (*format) {
-        case GST_FORMAT_TIME:
+        default:
           tmp =
               ((float) (modplug->mSoundFile->GetSongTime () *
                   modplug->mSoundFile->GetCurrentPos ()) /
               (float) modplug->mSoundFile->GetMaxPosition ());
           *value = (gint64) (tmp * GST_SECOND);
           break;
-        default:
-          res = FALSE;
-          break;
       }
-      break;
     default:
-      res = FALSE;
       break;
   }
 
