@@ -21,7 +21,7 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
-#include "gstmpegdemux.h"
+#include <gstmpegdemux.h>
 
 
 GST_DEBUG_CATEGORY_STATIC (gstmpegdemux_debug);
@@ -29,7 +29,7 @@ GST_DEBUG_CATEGORY_STATIC (gstmpegdemux_debug);
 
 GST_DEBUG_CATEGORY_EXTERN (GST_CAT_SEEK);
 
-#define PARSE_CLASS(o)  GST_MPEG_PARSE_CLASS (G_OBJECT_GET_CLASS (o))
+
 #define CLASS(o)  GST_MPEG_DEMUX_CLASS (G_OBJECT_GET_CLASS (o))
 
 /* elementfactory information */
@@ -51,8 +51,8 @@ enum
 {
   ARG_0,
   ARG_BIT_RATE,
-  ARG_MPEG2
-      /* FILL ME */
+  ARG_MPEG2,
+  /* FILL ME */
 };
 
 static GstStaticPadTemplate sink_template = GST_STATIC_PAD_TEMPLATE ("sink",
@@ -93,10 +93,6 @@ static void gst_mpeg_demux_send_data (GstMPEGParse * mpeg_parse,
     GstData * data, GstClockTime time);
 static void gst_mpeg_demux_send_discont (GstMPEGParse * mpeg_parse,
     GstClockTime time);
-static void gst_mpeg_demux_handle_discont (GstMPEGParse * mpeg_parse,
-    GstEvent * event);
-static void gst_mpeg_demux_send_event (GstMPEGParse * mpeg_parse,
-    GstEvent * event, GstClockTime time);
 
 static GstPad *gst_mpeg_demux_new_output_pad (GstMPEGDemux * mpeg_demux,
     const gchar * name, GstPadTemplate * temp);
@@ -126,10 +122,6 @@ static void gst_mpeg_demux_send_subbuffer (GstMPEGDemux * mpeg_demux,
 static void gst_mpeg_demux_process_private (GstMPEGDemux * mpeg_demux,
     GstBuffer * buffer,
     guint stream_nr, GstClockTime timestamp, guint headerlen, guint datalen);
-static void gst_mpeg_demux_synchronise_pads (GstMPEGDemux * mpeg_demux,
-    GstClockTime threshold, GstClockTime new_ts);
-static void gst_mpeg_demux_sync_stream_to_time (GstMPEGDemux * mpeg_demux,
-    GstMPEGStream * stream, GstClockTime last_ts);
 
 const GstFormat *gst_mpeg_demux_get_src_formats (GstPad * pad);
 
@@ -138,10 +130,6 @@ static gboolean normal_seek (GstPad * pad, GstEvent * event, gint64 * offset);
 
 static gboolean gst_mpeg_demux_handle_src_event (GstPad * pad,
     GstEvent * event);
-static void gst_mpeg_demux_reset (GstMPEGDemux * mpeg_demux);
-
-static gboolean gst_mpeg_demux_handle_src_query (GstPad * pad,
-    GstQueryType type, GstFormat * format, gint64 * value);
 
 static GstElementStateReturn gst_mpeg_demux_change_state (GstElement * element);
 
@@ -187,6 +175,9 @@ gst_mpeg_demux_base_init (GstMPEGDemuxClass * klass)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&sink_template));
+
   klass->video_template = gst_static_pad_template_get (&video_template);
   klass->audio_template = gst_static_pad_template_get (&audio_template);
   klass->private_template = gst_static_pad_template_get (&private_template);
@@ -219,8 +210,6 @@ gst_mpeg_demux_class_init (GstMPEGDemuxClass * klass)
   mpeg_parse_class->parse_pes = gst_mpeg_demux_parse_pes;
   mpeg_parse_class->send_data = gst_mpeg_demux_send_data;
   mpeg_parse_class->send_discont = gst_mpeg_demux_send_discont;
-  mpeg_parse_class->handle_discont = gst_mpeg_demux_handle_discont;
-  mpeg_parse_class->send_event = gst_mpeg_demux_send_event;
 
   klass->new_output_pad = gst_mpeg_demux_new_output_pad;
   klass->init_stream = gst_mpeg_demux_init_stream;
@@ -229,18 +218,20 @@ gst_mpeg_demux_class_init (GstMPEGDemuxClass * klass)
   klass->get_private_stream = gst_mpeg_demux_get_private_stream;
   klass->send_subbuffer = gst_mpeg_demux_send_subbuffer;
   klass->process_private = gst_mpeg_demux_process_private;
-  klass->synchronise_pads = gst_mpeg_demux_synchronise_pads;
-  klass->sync_stream_to_time = gst_mpeg_demux_sync_stream_to_time;
-
-  /* we have our own sink pad template, but don't use it in subclasses */
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&sink_template));
 }
 
 static void
 gst_mpeg_demux_init (GstMPEGDemux * mpeg_demux)
 {
   gint i;
+  GstMPEGParse *mpeg_parse = GST_MPEG_PARSE (mpeg_demux);
+
+  gst_element_remove_pad (GST_ELEMENT (mpeg_parse), mpeg_parse->sinkpad);
+  mpeg_parse->sinkpad =
+      gst_pad_new_from_template (gst_static_pad_template_get (&sink_template),
+      "sink");
+  gst_element_add_pad (GST_ELEMENT (mpeg_parse), mpeg_parse->sinkpad);
+  gst_element_remove_pad (GST_ELEMENT (mpeg_parse), mpeg_parse->srcpad);
 
   /* i think everything is already zero'd, but oh well */
   for (i = 0; i < GST_MPEG_DEMUX_NUM_VIDEO_STREAMS; i++) {
@@ -254,9 +245,6 @@ gst_mpeg_demux_init (GstMPEGDemux * mpeg_demux)
   }
 
   mpeg_demux->adjust = 0;
-  mpeg_demux->max_gap = GST_CLOCK_TIME_NONE;
-  mpeg_demux->max_gap_tolerance = GST_CLOCK_TIME_NONE;
-  mpeg_demux->just_flushed = FALSE;
 
   GST_FLAG_SET (mpeg_demux, GST_ELEMENT_EVENT_AWARE);
 }
@@ -265,20 +253,15 @@ static void
 gst_mpeg_demux_send_data (GstMPEGParse * mpeg_parse, GstData * data,
     GstClockTime time)
 {
+  /* GstMPEGDemux *mpeg_demux = GST_MPEG_DEMUX (mpeg_parse); */
+
   if (GST_IS_BUFFER (data)) {
     gst_buffer_unref (GST_BUFFER (data));
   } else {
     GstEvent *event = GST_EVENT (data);
 
     switch (GST_EVENT_TYPE (event)) {
-      case GST_EVENT_FILLER:
-      case GST_EVENT_DISCONTINUOUS:
-      case GST_EVENT_FLUSH:
-        PARSE_CLASS (mpeg_parse)->send_event (mpeg_parse, event,
-            GST_CLOCK_TIME_NONE);
-        break;
       default:
-        /* Propagate the event normally. */
         gst_pad_event_default (mpeg_parse->sinkpad, event);
         break;
     }
@@ -289,86 +272,40 @@ static void
 gst_mpeg_demux_send_discont (GstMPEGParse * mpeg_parse, GstClockTime time)
 {
   GstMPEGDemux *mpeg_demux = GST_MPEG_DEMUX (mpeg_parse);
-
-  if (GST_CLOCK_TIME_IS_VALID (time))
-    time += mpeg_demux->adjust;
-
-  if (!mpeg_demux->just_flushed) {
-    GST_DEBUG_OBJECT (mpeg_parse, "Discont without flush, ts = %llu", time);
-    /* Add padding to the end to make sure all streams end at the same timestamp */
-    CLASS (mpeg_demux)->synchronise_pads (mpeg_demux,
-        mpeg_parse->current_ts + mpeg_demux->adjust + (GST_SECOND / 20),
-        mpeg_parse->current_ts + mpeg_demux->adjust + (GST_SECOND / 20));
-  } else {
-    GST_DEBUG_OBJECT (mpeg_parse, "Discont after flush, ts = %llu", time);
-  }
-  mpeg_demux->just_flushed = FALSE;
-
-  parent_class->send_discont (mpeg_parse, time);
-}
-
-static void
-gst_mpeg_demux_send_event (GstMPEGParse * mpeg_parse, GstEvent * event,
-    GstClockTime time)
-{
-  /*
-   * Distribute the event to all active pads
-   */
-  GstMPEGDemux *mpeg_demux = GST_MPEG_DEMUX (mpeg_parse);
+  GstEvent *discont;
   gint i;
 
-  if (GST_EVENT_TYPE (event) == GST_EVENT_FLUSH) {
-    GST_DEBUG_OBJECT (mpeg_demux, "Sending flush event");
-    mpeg_demux->just_flushed = TRUE;
-  }
+  GST_DEBUG_OBJECT (mpeg_demux, "discont %" G_GUINT64_FORMAT, time);
 
   for (i = 0; i < GST_MPEG_DEMUX_NUM_VIDEO_STREAMS; i++) {
-    if (mpeg_demux->video_stream[i]) {
-      if (GST_PAD_IS_USABLE (mpeg_demux->video_stream[i]->pad)) {
-        gst_event_ref (event);
-        gst_pad_push (mpeg_demux->video_stream[i]->pad, GST_DATA (event));
-      }
-      if (GST_CLOCK_TIME_IS_VALID (time))
-        mpeg_demux->video_stream[i]->cur_ts = time;
+    if (mpeg_demux->video_stream[i] &&
+        GST_PAD_IS_USABLE (mpeg_demux->video_stream[i]->pad)) {
+      discont = gst_event_new_discontinuous (FALSE, GST_FORMAT_TIME,
+          time, NULL);
+
+      gst_pad_push (mpeg_demux->video_stream[i]->pad, GST_DATA (discont));
     }
   }
 
   for (i = 0; i < GST_MPEG_DEMUX_NUM_AUDIO_STREAMS; i++) {
-    if (mpeg_demux->audio_stream[i]) {
-      if (GST_PAD_IS_USABLE (mpeg_demux->audio_stream[i]->pad)) {
-        gst_event_ref (event);
-        gst_pad_push (mpeg_demux->audio_stream[i]->pad, GST_DATA (event));
-      }
-      if (GST_CLOCK_TIME_IS_VALID (time))
-        mpeg_demux->audio_stream[i]->cur_ts = time;
+    if (mpeg_demux->audio_stream[i] &&
+        GST_PAD_IS_USABLE (mpeg_demux->audio_stream[i]->pad)) {
+      discont = gst_event_new_discontinuous (FALSE, GST_FORMAT_TIME,
+          time, NULL);
+
+      gst_pad_push (mpeg_demux->audio_stream[i]->pad, GST_DATA (discont));
     }
   }
 
   for (i = 0; i < GST_MPEG_DEMUX_NUM_PRIVATE_STREAMS; i++) {
-    if (mpeg_demux->private_stream[i]) {
-      if (GST_PAD_IS_USABLE (mpeg_demux->private_stream[i]->pad)) {
-        gst_event_ref (event);
-        gst_pad_push (mpeg_demux->private_stream[i]->pad, GST_DATA (event));
-      }
-      if (GST_CLOCK_TIME_IS_VALID (time))
-        mpeg_demux->private_stream[i]->cur_ts = time;
+    if (mpeg_demux->private_stream[i] &&
+        GST_PAD_IS_USABLE (mpeg_demux->private_stream[i]->pad)) {
+      discont = gst_event_new_discontinuous (FALSE, GST_FORMAT_TIME,
+          time, NULL);
+
+      gst_pad_push (mpeg_demux->private_stream[i]->pad, GST_DATA (discont));
     }
   }
-
-  parent_class->send_event (mpeg_parse, event, time);
-}
-
-static void
-gst_mpeg_demux_handle_discont (GstMPEGParse * mpeg_parse, GstEvent * event)
-{
-  GstMPEGDemux *mpeg_demux = GST_MPEG_DEMUX (mpeg_parse);
-
-  if (GST_EVENT_DISCONT_NEW_MEDIA (event)) {
-    gst_mpeg_demux_reset (mpeg_demux);
-  }
-
-  if (parent_class->handle_discont != NULL)
-    parent_class->handle_discont (mpeg_parse, event);
 }
 
 static gint
@@ -394,13 +331,14 @@ gst_mpeg_demux_new_output_pad (GstMPEGDemux * mpeg_demux,
   GstPad *pad;
 
   pad = gst_pad_new_from_template (temp, name);
+  gst_element_add_pad (GST_ELEMENT (mpeg_demux), pad);
 
   gst_pad_set_formats_function (pad, gst_mpeg_demux_get_src_formats);
   gst_pad_set_convert_function (pad, gst_mpeg_parse_convert_src);
   gst_pad_set_event_mask_function (pad, gst_mpeg_parse_get_src_event_masks);
   gst_pad_set_event_function (pad, gst_mpeg_demux_handle_src_event);
   gst_pad_set_query_type_function (pad, gst_mpeg_parse_get_src_query_types);
-  gst_pad_set_query_function (pad, gst_mpeg_demux_handle_src_query);
+  gst_pad_set_query_function (pad, gst_mpeg_parse_handle_src_query);
   gst_pad_use_explicit_caps (pad);
 
   return pad;
@@ -420,9 +358,6 @@ gst_mpeg_demux_init_stream (GstMPEGDemux * mpeg_demux,
   if (mpeg_demux->index) {
     str->index_id = _demux_get_writer_id (mpeg_demux->index, str->pad);
   }
-
-  str->cur_ts = 0;
-  str->scr_offs = 0;
 }
 
 static GstMPEGStream *
@@ -434,7 +369,6 @@ gst_mpeg_demux_get_video_stream (GstMPEGDemux * mpeg_demux,
   GstMPEGVideoStream *video_str;
   gchar *name;
   GstCaps *caps;
-  gboolean set_caps = FALSE;
 
   g_return_val_if_fail (stream_nr < GST_MPEG_DEMUX_NUM_VIDEO_STREAMS, NULL);
   g_return_val_if_fail (type > GST_MPEG_DEMUX_VIDEO_UNKNOWN &&
@@ -445,6 +379,7 @@ gst_mpeg_demux_get_video_stream (GstMPEGDemux * mpeg_demux,
   if (str == NULL) {
     video_str = g_new0 (GstMPEGVideoStream, 1);
     str = (GstMPEGStream *) video_str;
+    str->type = GST_MPEG_DEMUX_VIDEO_UNKNOWN;
 
     name = g_strdup_printf ("video_%02d", stream_nr);
     CLASS (mpeg_demux)->init_stream (mpeg_demux, type, str, stream_nr, name,
@@ -452,8 +387,6 @@ gst_mpeg_demux_get_video_stream (GstMPEGDemux * mpeg_demux,
     g_free (name);
 
     mpeg_demux->video_stream[stream_nr] = str;
-
-    set_caps = TRUE;
   } else {
     /* This stream may have been created by a derived class, reset the
        size. */
@@ -461,35 +394,17 @@ gst_mpeg_demux_get_video_stream (GstMPEGDemux * mpeg_demux,
     mpeg_demux->video_stream[stream_nr] = str = (GstMPEGStream *) video_str;
   }
 
-  if (set_caps || video_str->mpeg_version != mpeg_version) {
-    gchar *codec;
-    GstTagList *list;
-
+  if (str->type != GST_MPEG_DEMUX_VIDEO_MPEG ||
+      video_str->mpeg_version != mpeg_version) {
     /* We need to set new caps for this pad. */
     caps = gst_caps_new_simple ("video/mpeg",
         "mpegversion", G_TYPE_INT, mpeg_version,
         "systemstream", G_TYPE_BOOLEAN, FALSE, NULL);
-    if (!gst_pad_set_explicit_caps (str->pad, caps)) {
-      GST_ELEMENT_ERROR (GST_ELEMENT (mpeg_demux),
-          CORE, NEGOTIATION, (NULL), ("failed to set caps"));
-      gst_caps_free (caps);
-      gst_element_add_pad (GST_ELEMENT (mpeg_demux), str->pad);
-      return str;
-    }
-    gst_caps_free (caps);
-    gst_element_add_pad (GST_ELEMENT (mpeg_demux), str->pad);
+    gst_pad_set_explicit_caps (str->pad, caps);
 
     /* Store the current values. */
+    str->type = GST_MPEG_DEMUX_VIDEO_MPEG;
     video_str->mpeg_version = mpeg_version;
-
-    /* set stream metadata */
-    codec = g_strdup_printf ("MPEG-%d video", mpeg_version);
-    list = gst_tag_list_new ();
-    gst_tag_list_add (list, GST_TAG_MERGE_REPLACE,
-        GST_TAG_VIDEO_CODEC, codec, NULL);
-    g_free (codec);
-    gst_element_found_tags_for_pad (GST_ELEMENT (mpeg_demux),
-        str->pad, 0, list);
   }
 
   return str;
@@ -502,21 +417,16 @@ gst_mpeg_demux_get_audio_stream (GstMPEGDemux * mpeg_demux,
   GstMPEGStream *str;
   gchar *name;
   GstCaps *caps;
-  gboolean set_caps = FALSE;
 
   g_return_val_if_fail (stream_nr < GST_MPEG_DEMUX_NUM_AUDIO_STREAMS, NULL);
   g_return_val_if_fail (type > GST_MPEG_DEMUX_AUDIO_UNKNOWN &&
       type < GST_MPEG_DEMUX_AUDIO_LAST, NULL);
 
   str = mpeg_demux->audio_stream[stream_nr];
-  if (str && str->type != type) {
-    gst_element_remove_pad (GST_ELEMENT (mpeg_demux), str->pad);
-    g_free (str);
-    str = mpeg_demux->audio_stream[stream_nr] = NULL;
-  }
 
   if (str == NULL) {
     str = g_new0 (GstMPEGStream, 1);
+    str->type = GST_MPEG_DEMUX_AUDIO_MPEG;
 
     name = g_strdup_printf ("audio_%02d", stream_nr);
     CLASS (mpeg_demux)->init_stream (mpeg_demux, type, str, stream_nr, name,
@@ -524,37 +434,19 @@ gst_mpeg_demux_get_audio_stream (GstMPEGDemux * mpeg_demux,
     g_free (name);
 
     mpeg_demux->audio_stream[stream_nr] = str;
-
-    /* new pad, set caps */
-    set_caps = TRUE;
   } else {
     /* This stream may have been created by a derived class, reset the
        size. */
     str = g_renew (GstMPEGStream, str, 1);
   }
 
-  if (set_caps) {
-    GstTagList *list;
-
+  if (str->type != GST_MPEG_DEMUX_AUDIO_MPEG) {
     /* We need to set new caps for this pad. */
     caps = gst_caps_new_simple ("audio/mpeg",
         "mpegversion", G_TYPE_INT, 1, NULL);
-    if (!gst_pad_set_explicit_caps (str->pad, caps)) {
-      GST_ELEMENT_ERROR (GST_ELEMENT (mpeg_demux),
-          CORE, NEGOTIATION, (NULL), ("failed to set caps"));
-      gst_caps_free (caps);
-      gst_element_add_pad (GST_ELEMENT (mpeg_demux), str->pad);
-      return str;
-    }
-    gst_caps_free (caps);
-    gst_element_add_pad (GST_ELEMENT (mpeg_demux), str->pad);
+    gst_pad_set_explicit_caps (str->pad, caps);
 
-    /* stream metadata */
-    list = gst_tag_list_new ();
-    gst_tag_list_add (list, GST_TAG_MERGE_REPLACE,
-        GST_TAG_AUDIO_CODEC, "MPEG-1 audio", NULL);
-    gst_element_found_tags_for_pad (GST_ELEMENT (mpeg_demux),
-        str->pad, 0, list);
+    str->type = GST_MPEG_DEMUX_AUDIO_MPEG;
   }
 
   return str;
@@ -577,7 +469,6 @@ gst_mpeg_demux_get_private_stream (GstMPEGDemux * mpeg_demux,
     CLASS (mpeg_demux)->init_stream (mpeg_demux, type, str, stream_nr, name,
         CLASS (mpeg_demux)->private_template);
     g_free (name);
-    gst_element_add_pad (GST_ELEMENT (mpeg_demux), str->pad);
 
     mpeg_demux->private_stream[stream_nr] = str;
   }
@@ -608,7 +499,7 @@ gst_mpeg_demux_parse_syshead (GstMPEGParse * mpeg_parse, GstBuffer * buffer)
   buf = GST_BUFFER_DATA (buffer);
   buf += 4;
 
-  header_length = GST_READ_UINT16_BE (buf);
+  header_length = GUINT16_FROM_BE (*(guint16 *) buf);
   GST_DEBUG_OBJECT (mpeg_demux, "header_length %d", header_length);
   buf += 2;
 
@@ -628,9 +519,6 @@ gst_mpeg_demux_parse_syshead (GstMPEGParse * mpeg_parse, GstBuffer * buffer)
     gint stream_count = (header_length - 6) / 3;
     gint i, j = 0;
 
-    /* Reset the total_size_bound before counting it up */
-    mpeg_demux->total_size_bound = 0;
-
     GST_DEBUG_OBJECT (mpeg_demux, "number of streams: %d ", stream_count);
 
     for (i = 0; i < stream_count; i++) {
@@ -682,7 +570,7 @@ gst_mpeg_demux_parse_syshead (GstMPEGParse * mpeg_parse, GstBuffer * buffer)
         outstream = CLASS (mpeg_demux)->get_video_stream (mpeg_demux,
             stream_id - 0xE0, GST_MPEG_DEMUX_VIDEO_MPEG, &mpeg_version);
       } else {
-        GST_WARNING_OBJECT (mpeg_demux, "unknown stream id 0x%02x", stream_id);
+        GST_WARNING_OBJECT (mpeg_demux, "unkown stream id 0x%02x", stream_id);
       }
 
       GST_DEBUG_OBJECT (mpeg_demux, "STD_buffer_bound_scale %d",
@@ -698,6 +586,19 @@ gst_mpeg_demux_parse_syshead (GstMPEGParse * mpeg_parse, GstBuffer * buffer)
           outstream->index_id =
               _demux_get_writer_id (mpeg_demux->index, outstream->pad);
         }
+
+        if (GST_PAD_IS_USABLE (outstream->pad)) {
+          GstEvent *event;
+          gint64 time;
+
+          time = MPEGTIME_TO_GSTTIME (mpeg_parse->current_scr
+              + mpeg_parse->adjust) + mpeg_demux->adjust;
+
+          event = gst_event_new_discontinuous (FALSE, GST_FORMAT_TIME,
+              MPEGTIME_TO_GSTTIME (time), NULL);
+
+          gst_pad_push (outstream->pad, GST_DATA (event));
+        }
       }
 
       j++;
@@ -731,7 +632,7 @@ gst_mpeg_demux_parse_packet (GstMPEGParse * mpeg_parse, GstBuffer * buffer)
   buf += 4;
 
   /* start parsing */
-  packet_length = GST_READ_UINT16_BE (buf);
+  packet_length = GUINT16_FROM_BE (*((guint16 *) buf));
 
   GST_DEBUG_OBJECT (mpeg_demux, "got packet_length %d", packet_length);
   headerlen = 2;
@@ -765,9 +666,9 @@ gst_mpeg_demux_parse_packet (GstMPEGParse * mpeg_parse, GstBuffer * buffer)
           case 0x20:
             /* pts:3 ! 1 ! pts:15 ! 1 | pts:15 ! 1 */
             pts = ((guint64) (bits & 0x0E)) << 29;
-            pts |= ((guint64) (*buf++)) << 22;
+            pts |= ((guint64) * buf++) << 22;
             pts |= ((guint64) (*buf++ & 0xFE)) << 14;
-            pts |= ((guint64) (*buf++)) << 7;
+            pts |= ((guint64) * buf++) << 7;
             pts |= ((guint64) (*buf++ & 0xFE)) >> 1;
 
             GST_DEBUG_OBJECT (mpeg_demux, "PTS = %" G_GUINT64_FORMAT, pts);
@@ -776,9 +677,9 @@ gst_mpeg_demux_parse_packet (GstMPEGParse * mpeg_parse, GstBuffer * buffer)
           case 0x30:
             /* pts:3 ! 1 ! pts:15 ! 1 | pts:15 ! 1 */
             pts = ((guint64) (bits & 0x0E)) << 29;
-            pts |= ((guint64) (*buf++)) << 22;
+            pts |= ((guint64) * buf++) << 22;
             pts |= ((guint64) (*buf++ & 0xFE)) << 14;
-            pts |= ((guint64) (*buf++)) << 7;
+            pts |= ((guint64) * buf++) << 7;
             pts |= ((guint64) (*buf++ & 0xFE)) >> 1;
 
             /* sync:4 ! pts:3 ! 1 ! pts:15 ! 1 | pts:15 ! 1 */
@@ -813,18 +714,12 @@ done:
 
   /* calculate the amount of real data in this packet */
   datalen = packet_length - headerlen + 2;
-
   GST_DEBUG_OBJECT (mpeg_demux, "headerlen is %d, datalen is %d",
       headerlen, datalen);
 
   if (pts != -1) {
     pts += mpeg_parse->adjust;
     timestamp = MPEGTIME_TO_GSTTIME (pts) + mpeg_demux->adjust;
-
-    /* this apparently happens for some input were headers are
-     * rewritten to make time start at zero... */
-    if ((gint64) timestamp < 0)
-      timestamp = 0;
   } else {
     timestamp = GST_CLOCK_TIME_NONE;
   }
@@ -857,7 +752,7 @@ done:
     CLASS (mpeg_demux)->send_subbuffer (mpeg_demux, outstream, buffer,
         timestamp, headerlen + 4, datalen);
   } else {
-    GST_WARNING_OBJECT (mpeg_demux, "unknown stream id 0x%02x", id);
+    GST_WARNING_OBJECT (mpeg_demux, "unkown stream id 0x%02x", id);
   }
 
   return TRUE;
@@ -874,7 +769,7 @@ gst_mpeg_demux_parse_pes (GstMPEGParse * mpeg_parse, GstBuffer * buffer)
 
   guint16 datalen;
   guint16 headerlen;
-  GstClockTime timestamp;
+  GstClockTime timestamp = GST_CLOCK_TIME_NONE;
 
   GstMPEGStream *outstream = NULL;
   guint8 *buf;
@@ -884,7 +779,7 @@ gst_mpeg_demux_parse_pes (GstMPEGParse * mpeg_parse, GstBuffer * buffer)
   buf += 4;
 
   /* start parsing */
-  packet_length = GST_READ_UINT16_BE (buf);
+  packet_length = GUINT16_FROM_BE (*((guint16 *) buf));
 
   GST_DEBUG_OBJECT (mpeg_demux, "packet_length %d", packet_length);
   buf += 2;
@@ -914,12 +809,11 @@ gst_mpeg_demux_parse_pes (GstMPEGParse * mpeg_parse, GstBuffer * buffer)
       pts |= ((guint64) * buf++) << 7;
       pts |= ((guint64) (*buf++ & 0xFE)) >> 1;
 
-      timestamp =
-          MPEGTIME_TO_GSTTIME (pts + mpeg_parse->adjust) + mpeg_demux->adjust;
+      GST_DEBUG_OBJECT (mpeg_demux, "0x%02x PTS = %" G_GUINT64_FORMAT,
+          id, MPEGTIME_TO_GSTTIME (pts));
 
-      GST_DEBUG_OBJECT (mpeg_demux,
-          "0x%02x (% " G_GINT64_FORMAT ") PTS = %" G_GUINT64_FORMAT, id, pts,
-          MPEGTIME_TO_GSTTIME (pts));
+      pts += mpeg_parse->adjust;
+      timestamp = MPEGTIME_TO_GSTTIME (pts) + mpeg_demux->adjust;;
     } else {
       timestamp = GST_CLOCK_TIME_NONE;
     }
@@ -954,8 +848,6 @@ gst_mpeg_demux_parse_pes (GstMPEGParse * mpeg_parse, GstBuffer * buffer)
     /* constant corresponds to the 2 bytes of the packet length. */
     headerlen = 2;
     datalen = packet_length;
-
-    timestamp = GST_CLOCK_TIME_NONE;
   }
 
   GST_DEBUG_OBJECT (mpeg_demux, "headerlen is %d, datalen is %d",
@@ -989,7 +881,7 @@ gst_mpeg_demux_parse_pes (GstMPEGParse * mpeg_parse, GstBuffer * buffer)
     CLASS (mpeg_demux)->send_subbuffer (mpeg_demux, outstream, buffer,
         timestamp, headerlen + 4, datalen);
   } else {
-    GST_WARNING_OBJECT (mpeg_demux, "unknown stream id 0x%02x", id);
+    GST_WARNING_OBJECT (mpeg_demux, "unkown stream id 0x%02x", id);
   }
 
   return TRUE;
@@ -1000,54 +892,27 @@ gst_mpeg_demux_send_subbuffer (GstMPEGDemux * mpeg_demux,
     GstMPEGStream * outstream, GstBuffer * buffer,
     GstClockTime timestamp, guint offset, guint size)
 {
-  GstMPEGParse *mpeg_parse = GST_MPEG_PARSE (mpeg_demux);
   GstBuffer *outbuf;
 
-  mpeg_demux->just_flushed = FALSE;
-
-  if (timestamp != GST_CLOCK_TIME_NONE) {
-    outstream->cur_ts = timestamp;
-    outstream->scr_offs =
-        GST_CLOCK_DIFF (timestamp, mpeg_parse->current_ts + mpeg_demux->adjust);
-    if (outstream->scr_offs < 0)
-      outstream->scr_offs = 0;
-
-    if (mpeg_demux->index != NULL) {
-      /* Register a new index position. */
-      gst_index_add_association (mpeg_demux->index,
-          outstream->index_id, 0,
-          GST_FORMAT_BYTES,
-          GST_BUFFER_OFFSET (buffer), GST_FORMAT_TIME, timestamp, 0);
-    }
-  } else {
-    outstream->cur_ts =
-        mpeg_parse->current_ts + mpeg_demux->adjust + outstream->scr_offs;
+  if (timestamp != GST_CLOCK_TIME_NONE && mpeg_demux->index != NULL) {
+    /* Register a new index position. */
+    gst_index_add_association (mpeg_demux->index,
+        outstream->index_id, 0,
+        GST_FORMAT_BYTES,
+        GST_BUFFER_OFFSET (buffer), GST_FORMAT_TIME, timestamp, 0);
   }
 
   if (!GST_PAD_IS_USABLE (outstream->pad) || (size == 0)) {
     return;
   }
 
-  GST_DEBUG_OBJECT (mpeg_demux, "Creating subbuffer size %d, time=%"
-      GST_TIME_FORMAT, size, GST_TIME_ARGS (timestamp));
+  GST_DEBUG_OBJECT (mpeg_demux, "Creating subbuffer size %d", size);
   outbuf = gst_buffer_create_sub (buffer, offset, size);
 
   GST_BUFFER_TIMESTAMP (outbuf) = timestamp;
   GST_BUFFER_OFFSET (outbuf) = GST_BUFFER_OFFSET (buffer) + offset;
 
   gst_pad_push (outstream->pad, GST_DATA (outbuf));
-
-  if (GST_CLOCK_TIME_IS_VALID (mpeg_demux->max_gap) &&
-      GST_CLOCK_TIME_IS_VALID (mpeg_parse->current_ts) &&
-      (mpeg_parse->current_ts + mpeg_demux->adjust > mpeg_demux->max_gap)) {
-    GstClockTime threshold =
-        GST_CLOCK_DIFF (mpeg_parse->current_ts + mpeg_demux->adjust,
-        mpeg_demux->max_gap);
-
-    CLASS (mpeg_demux)->synchronise_pads (mpeg_demux, threshold,
-        mpeg_parse->current_ts + mpeg_demux->adjust -
-        mpeg_demux->max_gap_tolerance);
-  }
 }
 
 static void
@@ -1063,78 +928,6 @@ gst_mpeg_demux_process_private (GstMPEGDemux * mpeg_demux,
       timestamp, headerlen + 4, datalen);
 }
 
-static void
-gst_mpeg_demux_synchronise_pads (GstMPEGDemux * mpeg_demux,
-    GstClockTime threshold, GstClockTime new_ts)
-{
-  /*
-   * Send a filler event to any pad with cur_ts < threshold to catch it up
-   */
-  gint i;
-
-  for (i = 0; i < GST_MPEG_DEMUX_NUM_VIDEO_STREAMS; i++)
-    if (mpeg_demux->video_stream[i]
-        && mpeg_demux->video_stream[i]->cur_ts < threshold) {
-      CLASS (mpeg_demux)->sync_stream_to_time (mpeg_demux,
-          mpeg_demux->video_stream[i], new_ts);
-      mpeg_demux->video_stream[i]->cur_ts = new_ts;
-    }
-
-  for (i = 0; i < GST_MPEG_DEMUX_NUM_AUDIO_STREAMS; i++)
-    if (mpeg_demux->audio_stream[i]
-        && mpeg_demux->audio_stream[i]->cur_ts < threshold) {
-      CLASS (mpeg_demux)->sync_stream_to_time (mpeg_demux,
-          mpeg_demux->audio_stream[i], new_ts);
-      mpeg_demux->audio_stream[i]->cur_ts = new_ts;
-    }
-
-  for (i = 0; i < GST_MPEG_DEMUX_NUM_PRIVATE_STREAMS; i++)
-    if (mpeg_demux->private_stream[i]
-        && mpeg_demux->private_stream[i]->cur_ts < threshold) {
-      CLASS (mpeg_demux)->sync_stream_to_time (mpeg_demux,
-          mpeg_demux->private_stream[i], new_ts);
-      mpeg_demux->private_stream[i]->cur_ts = new_ts;
-    }
-}
-
-/* Send a filler event on the indicated pad to catch it up to
- * last_ts. Query the pad for current time, and use that time
- * to set the duration of the filler event, otherwise we use
- * the last timestamp of the stream and rely on the sinks
- * to absorb any overlap with the decoded data.
- */
-static void
-gst_mpeg_demux_sync_stream_to_time (GstMPEGDemux * mpeg_demux,
-    GstMPEGStream * stream, GstClockTime last_ts)
-{
-  GstClockTime start_ts;
-  GstEvent *filler = NULL;
-  GstFormat fmt = GST_FORMAT_TIME;
-
-  if (!GST_PAD_PEER (stream->pad)
-      || !gst_pad_query (GST_PAD_PEER (stream->pad), GST_QUERY_POSITION, &fmt,
-          (gint64 *) & start_ts)) {
-    start_ts = stream->cur_ts;
-  }
-
-  if (start_ts < last_ts) {
-    filler = gst_event_new_filler_stamped (start_ts, GST_CLOCK_DIFF (last_ts,
-            start_ts));
-  }
-
-  if (filler) {
-    if (GST_PAD_IS_USABLE (stream->pad)) {
-      GST_LOG ("Advancing %s from %llu by %lld to %llu (diff %lld)",
-          gst_pad_get_name (stream->pad), stream->cur_ts,
-          gst_event_filler_get_duration (filler), last_ts,
-          GST_CLOCK_DIFF (last_ts, stream->cur_ts));
-
-      gst_pad_push (stream->pad, GST_DATA (filler));
-    } else
-      gst_event_unref (filler);
-  }
-}
-
 const GstFormat *
 gst_mpeg_demux_get_src_formats (GstPad * pad)
 {
@@ -1193,7 +986,7 @@ normal_seek (GstPad * pad, GstEvent * event, gint64 * offset)
   if (res) {
     *offset = MAX (GST_EVENT_SEEK_OFFSET (event) - adjust, 0);
 
-    GST_CAT_DEBUG (GST_CAT_SEEK, "%s:%s guesstimate %" G_GINT64_FORMAT
+    GST_CAT_DEBUG (GST_CAT_SEEK, "%s:%s guestimate %" G_GINT64_FORMAT
         " %s -> %" G_GINT64_FORMAT
         " (total_size_bound = %" G_GINT64_FORMAT ")",
         GST_DEBUG_PAD_NAME (pad),
@@ -1214,7 +1007,7 @@ gst_mpeg_demux_handle_src_event (GstPad * pad, GstEvent * event)
   switch (GST_EVENT_TYPE (event)) {
     case GST_EVENT_SEEK:
     {
-      gint64 desired_offset;
+      guint64 desired_offset;
 
       if (mpeg_demux->index)
         res = index_seek (pad, event, &desired_offset);
@@ -1232,13 +1025,9 @@ gst_mpeg_demux_handle_src_event (GstPad * pad, GstEvent * event)
       break;
     }
     case GST_EVENT_NAVIGATION:
-    {
-      GstPad *out = GST_PAD_PEER (GST_MPEG_PARSE (mpeg_demux)->sinkpad);
-
-      if (out && GST_PAD_IS_USABLE (out))
-        return gst_pad_send_event (out, event);
-    }
-      /* fall-through */
+      return gst_pad_send_event (GST_PAD_PEER (GST_MPEG_PARSE (mpeg_demux)->
+              sinkpad), event);
+      break;
     default:
       gst_event_unref (event);
       break;
@@ -1246,104 +1035,17 @@ gst_mpeg_demux_handle_src_event (GstPad * pad, GstEvent * event)
   return res;
 }
 
-static gboolean
-gst_mpeg_demux_handle_src_query (GstPad * pad, GstQueryType type,
-    GstFormat * format, gint64 * value)
-{
-  gboolean res;
-
-  res = gst_mpeg_parse_handle_src_query (pad, type, format, value);
-
-  if (res && (type == GST_QUERY_POSITION) && (format)
-      && (*format == GST_FORMAT_TIME)) {
-    GstMPEGDemux *mpeg_demux = GST_MPEG_DEMUX (gst_pad_get_parent (pad));
-
-    *value += mpeg_demux->adjust;
-  }
-
-  return res;
-}
-
-static void
-gst_mpeg_demux_reset (GstMPEGDemux * mpeg_demux)
-{
-  int i;
-
-  /* Reset the element */
-
-  GST_INFO ("Resetting the MPEG Demuxer");
-
-  /* free the streams , remove the pads */
-  /* filled in init_stream */
-  /* check get_audio/video_stream because it can be derivated */
-  for (i = 0; i < GST_MPEG_DEMUX_NUM_VIDEO_STREAMS; i++)
-    if (mpeg_demux->video_stream[i]) {
-      if (GST_PAD_IS_USABLE (mpeg_demux->video_stream[i]->pad)) {
-        gst_pad_push (mpeg_demux->video_stream[i]->pad,
-            GST_DATA (gst_event_new (GST_EVENT_EOS)));
-      }
-      gst_element_remove_pad (GST_ELEMENT (mpeg_demux),
-          mpeg_demux->video_stream[i]->pad);
-      g_free (mpeg_demux->video_stream[i]);
-      mpeg_demux->video_stream[i] = NULL;
-    }
-  for (i = 0; i < GST_MPEG_DEMUX_NUM_AUDIO_STREAMS; i++)
-    if (mpeg_demux->audio_stream[i]) {
-      if (GST_PAD_IS_USABLE (mpeg_demux->audio_stream[i]->pad)) {
-        gst_pad_push (mpeg_demux->audio_stream[i]->pad,
-            GST_DATA (gst_event_new (GST_EVENT_EOS)));
-      }
-      gst_element_remove_pad (GST_ELEMENT (mpeg_demux),
-          mpeg_demux->audio_stream[i]->pad);
-      g_free (mpeg_demux->audio_stream[i]);
-      mpeg_demux->audio_stream[i] = NULL;
-    }
-  for (i = 0; i < GST_MPEG_DEMUX_NUM_PRIVATE_STREAMS; i++)
-    if (mpeg_demux->private_stream[i]) {
-      if (GST_PAD_IS_USABLE (mpeg_demux->private_stream[i]->pad)) {
-        gst_pad_push (mpeg_demux->private_stream[i]->pad,
-            GST_DATA (gst_event_new (GST_EVENT_EOS)));
-      }
-      gst_element_remove_pad (GST_ELEMENT (mpeg_demux),
-          mpeg_demux->private_stream[i]->pad);
-      g_free (mpeg_demux->private_stream[i]);
-      mpeg_demux->private_stream[i] = NULL;
-    }
-
-  mpeg_demux->in_flush = FALSE;
-  mpeg_demux->header_length = 0;
-  mpeg_demux->rate_bound = 0;
-  mpeg_demux->audio_bound = 0;
-  mpeg_demux->video_bound = 0;
-  mpeg_demux->fixed = FALSE;
-  mpeg_demux->constrained = FALSE;
-  mpeg_demux->audio_lock = FALSE;
-  mpeg_demux->video_lock = FALSE;
-
-  mpeg_demux->packet_rate_restriction = FALSE;
-  mpeg_demux->total_size_bound = 0LL;
-
-  mpeg_demux->index = NULL;
-
-  /*
-   * Don't adjust things that are only for subclass use
-   * - if they changed it, they can reset it.
-   *
-   * mpeg_demux->adjust = 0;
-   * mpeg_demux->max_gap = GST_CLOCK_TIME_NONE;
-   * mpeg_demux->max_gap_tolerance = GST_CLOCK_TIME_NONE;
-   * mpeg_demux->just_flushed = FALSE;
-   */
-}
-
 static GstElementStateReturn
 gst_mpeg_demux_change_state (GstElement * element)
 {
-  GstMPEGDemux *mpeg_demux = GST_MPEG_DEMUX (element);
+  /* GstMPEGDemux *mpeg_demux = GST_MPEG_DEMUX (element); */
 
   switch (GST_STATE_TRANSITION (element)) {
+    case GST_STATE_READY_TO_PAUSED:
+      break;
     case GST_STATE_PAUSED_TO_READY:
-      gst_mpeg_demux_reset (mpeg_demux);
+      break;
+    case GST_STATE_READY_TO_NULL:
       break;
     default:
       break;
@@ -1379,5 +1081,5 @@ gboolean
 gst_mpeg_demux_plugin_init (GstPlugin * plugin)
 {
   return gst_element_register (plugin, "mpegdemux",
-      GST_RANK_SECONDARY, GST_TYPE_MPEG_DEMUX);
+      GST_RANK_PRIMARY, GST_TYPE_MPEG_DEMUX);
 }
