@@ -23,6 +23,7 @@
 
 #include <gst/gst.h>
 #include <gst/video/video.h>
+#include <gst/audio/audio.h>
 #include "synaescope.h"
 
 #define GST_TYPE_SYNAESTHESIA (gst_synaesthesia_get_type())
@@ -34,12 +35,12 @@
 typedef struct _GstSynaesthesia GstSynaesthesia;
 typedef struct _GstSynaesthesiaClass GstSynaesthesiaClass;
 
-struct _GstSynaesthesia {
+struct _GstSynaesthesia
+{
   GstElement element;
 
   /* pads */
-  GstPad *sinkpad,*srcpad;
-  GstBufferPool *peerpool;
+  GstPad *sinkpad, *srcpad;
 
   /* the timestamp of the next frame */
   guint64 next_time;
@@ -52,28 +53,30 @@ struct _GstSynaesthesia {
   gboolean first_buffer;
 };
 
-struct _GstSynaesthesiaClass {
+struct _GstSynaesthesiaClass
+{
   GstElementClass parent_class;
 };
 
-GType gst_synaesthesia_get_type(void);
+GType gst_synaesthesia_get_type (void);
 
 
 /* elementfactory information */
-static GstElementDetails gst_synaesthesia_details = GST_ELEMENT_DETAILS (
-  "Synaesthesia",
-  "Visualization",
-  "Creates video visualizations of audio input, using stereo and pitch information",
-  "Richard Boulton <richard@tartarus.org>"
-);
+static GstElementDetails gst_synaesthesia_details =
+GST_ELEMENT_DETAILS ("Synaesthesia",
+    "Visualization",
+    "Creates video visualizations of audio input, using stereo and pitch information",
+    "Richard Boulton <richard@tartarus.org>");
 
 /* signals and args */
-enum {
+enum
+{
   /* FILL ME */
   LAST_SIGNAL
 };
 
-enum {
+enum
+{
   ARG_0,
   ARG_WIDTH,
   ARG_HEIGHT,
@@ -81,59 +84,37 @@ enum {
   /* FILL ME */
 };
 
-GST_PAD_TEMPLATE_FACTORY (src_template,
-  "src",
-  GST_PAD_SRC,
-  GST_PAD_ALWAYS,
-  GST_CAPS_NEW (
-    "synaesthesiasrc",
-    "video/x-raw-rgb",
-      "bpp",		GST_PROPS_INT (32),
-      "depth",		GST_PROPS_INT (32),
-      "endianness", 	GST_PROPS_INT (G_BIG_ENDIAN),
-      "red_mask",   	GST_PROPS_INT (R_MASK_32),
-      "green_mask", 	GST_PROPS_INT (G_MASK_32),
-      "blue_mask",  	GST_PROPS_INT (B_MASK_32),
-      "width",		GST_PROPS_INT_RANGE (16, 4096),
-      "height",		GST_PROPS_INT_RANGE (16, 4096),
-      "framerate",	GST_PROPS_FLOAT_RANGE (0, G_MAXFLOAT)
-  )
-)
+static GstStaticPadTemplate gst_synaesthesia_src_template =
+GST_STATIC_PAD_TEMPLATE ("src",
+    GST_PAD_SRC,
+    GST_PAD_ALWAYS,
+    GST_STATIC_CAPS (GST_VIDEO_CAPS_xRGB_HOST_ENDIAN)
+    );
 
-GST_PAD_TEMPLATE_FACTORY (sink_template,
-  "sink",					/* the name of the pads */
-  GST_PAD_SINK,				/* type of the pad */
-  GST_PAD_ALWAYS,				/* ALWAYS/SOMETIMES */
-  GST_CAPS_NEW (
-    "synaesthesiasink",				/* the name of the caps */
-    "audio/x-raw-int",				/* the mime type of the caps */
-       /* Properties follow: */
-      "endianness", GST_PROPS_INT (G_BYTE_ORDER),
-      "signed",     GST_PROPS_BOOLEAN (TRUE),
-      "width",      GST_PROPS_INT (16),
-      "depth",      GST_PROPS_INT (16),
-      "rate",       GST_PROPS_INT_RANGE (8000, 96000),
-      "channels",   GST_PROPS_INT (2)
-  )
-)
+static GstStaticPadTemplate gst_synaesthesia_sink_template =
+GST_STATIC_PAD_TEMPLATE ("sink",
+    GST_PAD_SINK,
+    GST_PAD_ALWAYS,
+    GST_STATIC_CAPS (GST_AUDIO_INT_STANDARD_PAD_TEMPLATE_CAPS)
+    );
 
 
-static void		gst_synaesthesia_base_init	(gpointer g_class);
-static void		gst_synaesthesia_class_init	(GstSynaesthesiaClass *klass);
-static void		gst_synaesthesia_init		(GstSynaesthesia *synaesthesia);
+static void gst_synaesthesia_base_init (gpointer g_class);
+static void gst_synaesthesia_class_init (GstSynaesthesiaClass * klass);
+static void gst_synaesthesia_init (GstSynaesthesia * synaesthesia);
 
-static void		gst_synaesthesia_set_property	(GObject *object, guint prop_id, 
-						 const GValue *value, GParamSpec *pspec);
-static void		gst_synaesthesia_get_property	(GObject *object, guint prop_id, 
-						 GValue *value, GParamSpec *pspec);
+static void gst_synaesthesia_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec);
+static void gst_synaesthesia_get_property (GObject * object, guint prop_id,
+    GValue * value, GParamSpec * pspec);
 
-static void		gst_synaesthesia_chain		(GstPad *pad, GstData *_data);
+static void gst_synaesthesia_chain (GstPad * pad, GstData * _data);
 
 static GstElementStateReturn
-			gst_synaesthesia_change_state	(GstElement *element);
+gst_synaesthesia_change_state (GstElement * element);
 
-static GstPadLinkReturn 
-			gst_synaesthesia_sinkconnect 	(GstPad *pad, GstCaps *caps);
+static GstPadLinkReturn
+gst_synaesthesia_sink_link (GstPad * pad, const GstCaps * caps);
 
 static GstElementClass *parent_class = NULL;
 
@@ -144,9 +125,9 @@ gst_synaesthesia_get_type (void)
 
   if (!type) {
     static const GTypeInfo info = {
-      sizeof (GstSynaesthesiaClass),      
-      gst_synaesthesia_base_init,      
-      NULL,      
+      sizeof (GstSynaesthesiaClass),
+      gst_synaesthesia_base_init,
+      NULL,
       (GClassInitFunc) gst_synaesthesia_class_init,
       NULL,
       NULL,
@@ -154,7 +135,8 @@ gst_synaesthesia_get_type (void)
       0,
       (GInstanceInitFunc) gst_synaesthesia_init,
     };
-    type = g_type_register_static (GST_TYPE_ELEMENT, "GstSynaesthesia", &info, 0);
+    type =
+        g_type_register_static (GST_TYPE_ELEMENT, "GstSynaesthesia", &info, 0);
   }
   return type;
 }
@@ -166,29 +148,32 @@ gst_synaesthesia_base_init (gpointer g_class)
 
   gst_element_class_set_details (element_class, &gst_synaesthesia_details);
 
-  gst_element_class_add_pad_template (element_class, GST_PAD_TEMPLATE_GET (src_template));
-  gst_element_class_add_pad_template (element_class, GST_PAD_TEMPLATE_GET (sink_template));
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&gst_synaesthesia_src_template));
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&gst_synaesthesia_sink_template));
 }
+
 static void
-gst_synaesthesia_class_init(GstSynaesthesiaClass *klass)
+gst_synaesthesia_class_init (GstSynaesthesiaClass * klass)
 {
   GObjectClass *gobject_class;
   GstElementClass *gstelement_class;
 
-  gobject_class = (GObjectClass*) klass;
-  gstelement_class = (GstElementClass*) klass;
+  gobject_class = (GObjectClass *) klass;
+  gstelement_class = (GstElementClass *) klass;
 
   parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
 
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_WIDTH,
-    g_param_spec_int ("width","Width","The Width",
-                       1, 2048, 320, G_PARAM_READWRITE));
+      g_param_spec_int ("width", "Width", "The Width",
+          1, 2048, 320, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_HEIGHT,
-    g_param_spec_int ("height","Height","The height",
-                       1, 2048, 320, G_PARAM_READWRITE));
+      g_param_spec_int ("height", "Height", "The height",
+          1, 2048, 320, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_FPS,
-    g_param_spec_float ("fps","FPS","Frames per second",
-                       0., G_MAXFLOAT, 25., G_PARAM_READWRITE));
+      g_param_spec_float ("fps", "FPS", "Frames per second",
+          0., G_MAXFLOAT, 25., G_PARAM_READWRITE));
 
   gobject_class->set_property = gst_synaesthesia_set_property;
   gobject_class->get_property = gst_synaesthesia_get_property;
@@ -197,43 +182,42 @@ gst_synaesthesia_class_init(GstSynaesthesiaClass *klass)
 }
 
 static void
-gst_synaesthesia_init (GstSynaesthesia *synaesthesia)
+gst_synaesthesia_init (GstSynaesthesia * synaesthesia)
 {
   /* create the sink and src pads */
-  synaesthesia->sinkpad = gst_pad_new_from_template (
-		  GST_PAD_TEMPLATE_GET (sink_template ), "sink");
-  synaesthesia->srcpad = gst_pad_new_from_template (
-		  GST_PAD_TEMPLATE_GET (src_template ), "src");
+  synaesthesia->sinkpad =
+      gst_pad_new_from_template (gst_static_pad_template_get
+      (&gst_synaesthesia_sink_template), "sink");
+  synaesthesia->srcpad =
+      gst_pad_new_from_template (gst_static_pad_template_get
+      (&gst_synaesthesia_src_template), "src");
   gst_element_add_pad (GST_ELEMENT (synaesthesia), synaesthesia->sinkpad);
   gst_element_add_pad (GST_ELEMENT (synaesthesia), synaesthesia->srcpad);
 
   gst_pad_set_chain_function (synaesthesia->sinkpad, gst_synaesthesia_chain);
-  gst_pad_set_link_function (synaesthesia->sinkpad, gst_synaesthesia_sinkconnect);
+  gst_pad_set_link_function (synaesthesia->sinkpad, gst_synaesthesia_sink_link);
 
   GST_FLAG_SET (synaesthesia, GST_ELEMENT_EVENT_AWARE);
 
   /* reset the initial video state */
   synaesthesia->width = 320;
   synaesthesia->height = 200;
-  synaesthesia->fps = 25.; /* desired frame rate */
+  synaesthesia->fps = 25.;      /* desired frame rate */
 
 }
 
 static GstPadLinkReturn
-gst_synaesthesia_sinkconnect (GstPad *pad, GstCaps *caps)
+gst_synaesthesia_sink_link (GstPad * pad, const GstCaps * caps)
 {
   GstSynaesthesia *synaesthesia;
-  synaesthesia = GST_SYNAESTHESIA (gst_pad_get_parent (pad));
 
-  if (!GST_CAPS_IS_FIXED (caps)) {
-    return GST_PAD_LINK_DELAYED;
-  }
+  synaesthesia = GST_SYNAESTHESIA (gst_pad_get_parent (pad));
 
   return GST_PAD_LINK_OK;
 }
 
 static void
-gst_synaesthesia_chain (GstPad *pad, GstData *_data)
+gst_synaesthesia_chain (GstPad * pad, GstData * _data)
 {
   GstBuffer *bufin = GST_BUFFER (_data);
   GstSynaesthesia *synaesthesia;
@@ -253,6 +237,7 @@ gst_synaesthesia_chain (GstPad *pad, GstData *_data)
       case GST_EVENT_DISCONTINUOUS:
       {
         gint64 value = 0;
+
         gst_event_discont_get_value (event, GST_FORMAT_TIME, &value);
         synaesthesia->next_time = value;
       }
@@ -260,7 +245,7 @@ gst_synaesthesia_chain (GstPad *pad, GstData *_data)
         gst_pad_event_default (pad, event);
         break;
     }
-    return;     
+    return;
   }
 
   samples_in = GST_BUFFER_SIZE (bufin) / sizeof (gint16);
@@ -268,50 +253,30 @@ gst_synaesthesia_chain (GstPad *pad, GstData *_data)
   GST_DEBUG ("input buffer has %d samples", samples_in);
 
   /* FIXME: should really select the first 1024 samples after the timestamp. */
-  if (GST_BUFFER_TIMESTAMP (bufin) < synaesthesia->next_time || samples_in < 1024) {
-    GST_DEBUG ("timestamp is %" G_GUINT64_FORMAT ": want >= %" G_GUINT64_FORMAT, GST_BUFFER_TIMESTAMP (bufin), synaesthesia->next_time);
+  if (GST_BUFFER_TIMESTAMP (bufin) < synaesthesia->next_time
+      || samples_in < 1024) {
+    GST_DEBUG ("timestamp is %" G_GUINT64_FORMAT ": want >= %" G_GUINT64_FORMAT,
+        GST_BUFFER_TIMESTAMP (bufin), synaesthesia->next_time);
     gst_buffer_unref (bufin);
     return;
   }
 
   data = (gint16 *) GST_BUFFER_DATA (bufin);
-  for (i=0; i < 512; i++) {
+  for (i = 0; i < 512; i++) {
     synaesthesia->datain[0][i] = *data++;
     synaesthesia->datain[1][i] = *data++;
   }
 
   if (synaesthesia->first_buffer) {
-    GstCaps *caps;
-
     synaesthesia_init (synaesthesia->width, synaesthesia->height);
-	
-    GST_DEBUG ("making new pad");
 
-    caps = GST_CAPS_NEW (
-		     "synaesthesiasrc",
-		     "video/x-raw-rgb",
-		       "format", 	GST_PROPS_FOURCC (GST_STR_FOURCC ("RGB ")), 
-		       "bpp", 		GST_PROPS_INT (32), 
-		       "depth", 	GST_PROPS_INT (32), 
-		       "endianness", 	GST_PROPS_INT (G_BIG_ENDIAN), 
-		       "red_mask", 	GST_PROPS_INT (R_MASK_32), 
-		       "green_mask", 	GST_PROPS_INT (G_MASK_32), 
-		       "blue_mask", 	GST_PROPS_INT (B_MASK_32), 
-		       "width", 	GST_PROPS_INT (synaesthesia->width), 
-		       "height", 	GST_PROPS_INT (synaesthesia->height),
-                       "framerate",	GST_PROPS_FLOAT (synaesthesia->fps)
-		   );
-
-    if (gst_pad_try_set_caps (synaesthesia->srcpad, caps) <= 0) {
-      gst_element_error (GST_ELEMENT (synaesthesia), "could not set caps");
-      return;
-    }
     synaesthesia->first_buffer = FALSE;
   }
 
   bufout = gst_buffer_new ();
   GST_BUFFER_SIZE (bufout) = synaesthesia->width * synaesthesia->height * 4;
-  GST_BUFFER_DATA (bufout) = (guchar *) synaesthesia_update (synaesthesia->datain);
+  GST_BUFFER_DATA (bufout) =
+      (guchar *) synaesthesia_update (synaesthesia->datain);
   GST_BUFFER_TIMESTAMP (bufout) = synaesthesia->next_time;
   GST_BUFFER_FLAG_SET (bufout, GST_BUFFER_DONTFREE);
 
@@ -326,7 +291,8 @@ gst_synaesthesia_chain (GstPad *pad, GstData *_data)
 }
 
 static void
-gst_synaesthesia_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
+gst_synaesthesia_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec)
 {
   GstSynaesthesia *synaesthesia;
 
@@ -350,7 +316,8 @@ gst_synaesthesia_set_property (GObject *object, guint prop_id, const GValue *val
 }
 
 static void
-gst_synaesthesia_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
+gst_synaesthesia_get_property (GObject * object, guint prop_id, GValue * value,
+    GParamSpec * pspec)
 {
   GstSynaesthesia *synaesthesia;
 
@@ -374,7 +341,7 @@ gst_synaesthesia_get_property (GObject *object, guint prop_id, GValue *value, GP
 }
 
 static GstElementStateReturn
-gst_synaesthesia_change_state (GstElement *element)
+gst_synaesthesia_change_state (GstElement * element)
 {
   GstSynaesthesia *synaesthesia;
 
@@ -383,7 +350,6 @@ gst_synaesthesia_change_state (GstElement *element)
   switch (GST_STATE_TRANSITION (element)) {
     case GST_STATE_READY_TO_PAUSED:
       synaesthesia->next_time = 0;
-      synaesthesia->peerpool = NULL;
       synaesthesia->first_buffer = TRUE;
       break;
   }
@@ -396,20 +362,14 @@ gst_synaesthesia_change_state (GstElement *element)
 
 
 static gboolean
-plugin_init (GstPlugin *plugin)
+plugin_init (GstPlugin * plugin)
 {
-  return gst_element_register (plugin, "synaesthesia", GST_RANK_NONE, GST_TYPE_SYNAESTHESIA);
+  return gst_element_register (plugin, "synaesthesia", GST_RANK_NONE,
+      GST_TYPE_SYNAESTHESIA);
 }
 
-GST_PLUGIN_DEFINE (
-  GST_VERSION_MAJOR,
-  GST_VERSION_MINOR,
-  "synaesthesia",
-  "Creates video visualizations of audio input, using stereo and pitch information",
-  plugin_init,
-  VERSION,
-  "GPL",
-  GST_COPYRIGHT,
-  GST_PACKAGE,
-  GST_ORIGIN
-)
+GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
+    GST_VERSION_MINOR,
+    "synaesthesia",
+    "Creates video visualizations of audio input, using stereo and pitch information",
+    plugin_init, VERSION, "GPL", GST_PACKAGE, GST_ORIGIN)
