@@ -74,7 +74,7 @@ static GstStaticPadTemplate volume_sink_factory =
         "channels = (int) [ 1, MAX ], "
         "endianness = (int) BYTE_ORDER, "
         "width = (int) 32, "
-        "buffer-frames = (int) [ 0, MAX]; "
+        "buffer-frames = (int) [ 1, MAX]; "
         "audio/x-raw-int, "
         "channels = (int) [ 1, MAX ], "
         "rate = (int) [ 1,  MAX ], "
@@ -90,7 +90,7 @@ static GstStaticPadTemplate volume_src_factory = GST_STATIC_PAD_TEMPLATE ("src",
         "channels = (int) [ 1, MAX ], "
         "endianness = (int) BYTE_ORDER, "
         "width = (int) 32, "
-        "buffer-frames = (int) [ 0, MAX]; "
+        "buffer-frames = (int) [ 1, MAX]; "
         "audio/x-raw-int, "
         "channels = (int) [ 1, MAX ], "
         "rate = (int) [ 1,  MAX ], "
@@ -215,7 +215,9 @@ gst_volume_mixer_init (GstMixerClass * klass)
 static void
 gst_volume_dispose (GObject * object)
 {
-  GstVolume *volume = GST_VOLUME (object);
+  GstVolume *volume;
+
+  volume = GST_VOLUME (object);
 
   if (volume->tracklist) {
     if (volume->tracklist->data)
@@ -415,8 +417,6 @@ volume_chain_float (GstPad * pad, GstData * _data)
   filter = GST_VOLUME (GST_OBJECT_PARENT (pad));
   g_return_if_fail (GST_IS_VOLUME (filter));
 
-  GST_LOG_OBJECT (filter, "processing incoming float buffer with refcount %d",
-      GST_BUFFER_REFCOUNT_VALUE (buf));
   out_buf = gst_buffer_copy_on_write (buf);
 
   data = (gfloat *) GST_BUFFER_DATA (out_buf);
@@ -442,15 +442,12 @@ volume_chain_int16 (GstPad * pad, GstData * _data)
   gint16 *data;
   gint i, num_samples;
 
-  g_return_if_fail (_data);
   g_return_if_fail (GST_IS_PAD (pad));
   g_return_if_fail (buf != NULL);
 
   filter = GST_VOLUME (GST_OBJECT_PARENT (pad));
   g_return_if_fail (GST_IS_VOLUME (filter));
 
-  GST_LOG_OBJECT (filter, "processing incoming int16 buffer with refcount %d",
-      GST_BUFFER_REFCOUNT_VALUE (buf));
   out_buf = gst_buffer_copy_on_write (buf);
 
   data = (gint16 *) GST_BUFFER_DATA (out_buf);
@@ -483,6 +480,7 @@ volume_chain_int16 (GstPad * pad, GstData * _data)
   }
 
   gst_pad_push (filter->srcpad, GST_DATA (out_buf));
+
 }
 
 static void
